@@ -46,6 +46,14 @@
 #include "blockitem.h"
 #include "data.h"
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_BLOCK_MAX_ITEMS     100
+#define U61_BLOCK_PREVIEW_WIDTH   4
+#define U61_BLOCK_PREVIEW_HEIGHT  4
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -79,15 +87,12 @@ public:
     void center();
     void corner();
 
-    void draw(int x,int y,int size=U61_Data::SIZE_BIG);
-    void draw_preview(int x,int y,int size=U61_Data::SIZE_BIG);
-    void draw_anticipation(int x,int y,int size=U61_Data::SIZE_BIG);
+    void draw(int x,int y,int size=U61_DATA_SIZE_BIG);
+    void draw_preview(int x,int y,int size=U61_DATA_SIZE_BIG);
+    void draw_anticipation(int x,int y,int size=U61_DATA_SIZE_BIG);
     
-    static const int MAX_ITEMS=100;
 protected:
-    static const int PREVIEW_WIDTH=16;
-    static const int PREVIEW_HEIGHT=16;
-    U61_BlockItem items[MAX_ITEMS];
+    U61_BlockItem items[U61_BLOCK_MAX_ITEMS];
     int nb_items;
     int pos_x;
     int pos_y;
