@@ -46,9 +46,24 @@
 #include "debug.h"
 
 /*---------------------------------------------------------------------------
- variants
+ constants
  ---------------------------------------------------------------------------*/
 
+#define U61_CLIENTPROTOCOL_SEARCHING                10
+#define U61_CLIENTPROTOCOL_CONNECTED_TO_SERVER      11
+#define U61_CLIENTPROTOCOL_JOIN_DELAY_ELAPSED       12
+#define U61_CLIENTPROTOCOL_CHANNEL_FOUND            13
+#define U61_CLIENTPROTOCOL_SCRIPT_NAME_RECEIVED     30
+#define U61_CLIENTPROTOCOL_SCRIPT_RECEIVED          31
+#define U61_CLIENTPROTOCOL_ID0_RECEIVED             40
+#define U61_CLIENTPROTOCOL_ID1_RECEIVED             41
+#define U61_CLIENTPROTOCOL_INITIAL_SPEED_RECEIVED   42
+#define U61_CLIENTPROTOCOL_ACCELERATION_RECEIVED    43
+#define U61_CLIENTPROTOCOL_CURSE_DELAY_RECEIVED     44
+#define U61_CLIENTPROTOCOL_TIME_RECEIVED            45
+#define U61_CLIENTPROTOCOL_PLAYING                  60   
+#define U61_CLIENTPROTOCOL_CLOSED                   61
+
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
@@ -89,18 +104,18 @@ void U61_ClientProtocol::check_connection()
   int i;
   U61_Player *p;
 
-  if (stage!=CLOSED 
+  if (stage!=U61_CLIENTPROTOCOL_CLOSED 
       && game!=NULL 
       && game->receive_game_closed())
     {
-      stage=CLOSED;
+      stage=U61_CLIENTPROTOCOL_CLOSED;
       U61_LOG_DEBUG("stage=CLOSED");
       connection->close();
 
       /*
        * We kill all the remote players and let the game keep going locally
        */
-      for (i=0;i<U61_Dispatcher::MAX_PLAYER_ID;++i)
+      for (i=0;i<U61_DISPATCHER_MAX_PLAYER_ID;++i)
 	{
 	  p=U61_Global::game.find_player_by_id(i);
           if (p!=NULL && p->is_available() && !p->is_local())
@@ -118,50 +133,50 @@ void U61_ClientProtocol::check_connection()
  */
 int U61_ClientProtocol::send_next_packet()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   switch(stage)
     {
-    case BEGIN:
-      if ((result=start_searching())==DONE)
+    case U61_PROTOCOL_BEGIN:
+      if ((result=start_searching())==U61_PROTOCOL_DONE)
 	{
-	  stage=SEARCHING;
+	  stage=U61_CLIENTPROTOCOL_SEARCHING;
 	  U61_LOG_DEBUG("stage=SEARCHING");
 	}
       break;
-    case CONNECTED_TO_SERVER:
-      if ((result=join_delay())==DONE)
+    case U61_CLIENTPROTOCOL_CONNECTED_TO_SERVER:
+      if ((result=join_delay())==U61_PROTOCOL_DONE)
 	{
-	  stage=JOIN_DELAY_ELAPSED;
+	  stage=U61_CLIENTPROTOCOL_JOIN_DELAY_ELAPSED;
 	  U61_LOG_DEBUG("stage=JOIN_DELAY_ELAPSED");
 	}
       break;
-    case CHANNEL_FOUND:
-      if ((result=send_id(connection))==DONE)
+    case U61_CLIENTPROTOCOL_CHANNEL_FOUND:
+      if ((result=send_id(connection))==U61_PROTOCOL_DONE)
 	{
-	  stage=ID_SENT;
+	  stage=U61_PROTOCOL_ID_SENT;
 	  U61_LOG_DEBUG("stage=ID_SENT");
 	}
       break;
-    case ID_RECEIVED:
-      if ((result=send_version(connection))==DONE)
+    case U61_PROTOCOL_ID_RECEIVED:
+      if ((result=send_version(connection))==U61_PROTOCOL_DONE)
 	{
-	  stage=VERSION_SENT;
+	  stage=U61_PROTOCOL_VERSION_SENT;
 	  U61_LOG_DEBUG("stage=VERSION_SENT");
 	}
       break;
-    case TIME_RECEIVED:
-      if ((result=send_ready(connection))==DONE)
+    case U61_CLIENTPROTOCOL_TIME_RECEIVED:
+      if ((result=send_ready(connection))==U61_PROTOCOL_DONE)
 	{
-	  stage=READY_SENT;
+	  stage=U61_PROTOCOL_READY_SENT;
 	  U61_LOG_DEBUG("stage=READY_SENT");
 	}
       break;
-    case READY_RECEIVED:
+    case U61_PROTOCOL_READY_RECEIVED:
       start_game();
       dispatcher->open(connection);
       
-      stage=PLAYING;
+      stage=U61_CLIENTPROTOCOL_PLAYING;
       U61_LOG_DEBUG("stage=PLAYING");
       
       break;
@@ -178,98 +193,98 @@ int U61_ClientProtocol::send_next_packet()
  */
 int U61_ClientProtocol::recv_next_packet()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   switch(stage)
     {
-    case SEARCHING:
-      if ((result=connect_to_server())==DONE)
+    case U61_CLIENTPROTOCOL_SEARCHING:
+      if ((result=connect_to_server())==U61_PROTOCOL_DONE)
 	{
-	  stage=CONNECTED_TO_SERVER;
+	  stage=U61_CLIENTPROTOCOL_CONNECTED_TO_SERVER;
 	  U61_LOG_DEBUG("stage=CONNECTED_TO_SERVER");
 	}
       break;
-    case JOIN_DELAY_ELAPSED:
-      if ((result=find_channel())==DONE)
+    case U61_CLIENTPROTOCOL_JOIN_DELAY_ELAPSED:
+      if ((result=find_channel())==U61_PROTOCOL_DONE)
 	{
-	  stage=CHANNEL_FOUND;
+	  stage=U61_CLIENTPROTOCOL_CHANNEL_FOUND;
 	  U61_LOG_DEBUG("stage=CHANNEL_FOUND");
 	}
       break;
-    case ID_SENT:
-      if ((result=recv_id(connection))==DONE)
+    case U61_PROTOCOL_ID_SENT:
+      if ((result=recv_id(connection))==U61_PROTOCOL_DONE)
 	{  
-	  stage=ID_RECEIVED;
+	  stage=U61_PROTOCOL_ID_RECEIVED;
 	  U61_LOG_DEBUG("stage=ID_RECEIVED");
 	}
       break;
-    case VERSION_SENT:
-      if ((result=recv_version(connection))==DONE)
+    case U61_PROTOCOL_VERSION_SENT:
+      if ((result=recv_version(connection))==U61_PROTOCOL_DONE)
 	{
-	  stage=VERSION_RECEIVED;
+	  stage=U61_PROTOCOL_VERSION_RECEIVED;
 	  U61_LOG_DEBUG("stage=VERSION_RECEIVED");
 	}
       break;
-    case VERSION_RECEIVED:
-      if ((result=recv_script_name())==DONE)
+    case U61_PROTOCOL_VERSION_RECEIVED:
+      if ((result=recv_script_name())==U61_PROTOCOL_DONE)
 	{
-	  stage=SCRIPT_NAME_RECEIVED;
+	  stage=U61_CLIENTPROTOCOL_SCRIPT_NAME_RECEIVED;
 	  U61_LOG_DEBUG("stage=SCRIPT_NAME_RECEIVED");
 	}
       break;
-    case SCRIPT_NAME_RECEIVED:
-      if ((result=recv_script())==DONE)
+    case U61_CLIENTPROTOCOL_SCRIPT_NAME_RECEIVED:
+      if ((result=recv_script())==U61_PROTOCOL_DONE)
 	{
-	  stage=SCRIPT_RECEIVED;
+	  stage=U61_CLIENTPROTOCOL_SCRIPT_RECEIVED;
 	  U61_LOG_DEBUG("stage=SCRIPT_RECEIVED");
 	}
       break;
-    case SCRIPT_RECEIVED:
-      if ((result=recv_id0())==DONE)
+    case U61_CLIENTPROTOCOL_SCRIPT_RECEIVED:
+      if ((result=recv_id0())==U61_PROTOCOL_DONE)
 	{
-	  stage=ID0_RECEIVED;
+	  stage=U61_CLIENTPROTOCOL_ID0_RECEIVED;
 	  U61_LOG_DEBUG("stage=ID0_RECEIVED");
 	}
       break;
-    case ID0_RECEIVED:
-      if ((result=recv_id1())==DONE)
+    case U61_CLIENTPROTOCOL_ID0_RECEIVED:
+      if ((result=recv_id1())==U61_PROTOCOL_DONE)
 	{
-	  stage=ID1_RECEIVED;
+	  stage=U61_CLIENTPROTOCOL_ID1_RECEIVED;
 	  U61_LOG_DEBUG("stage=ID1_RECEIVED");
 	}
       break;
-    case ID1_RECEIVED:
-      if ((result=recv_initial_speed())==DONE)
+    case U61_CLIENTPROTOCOL_ID1_RECEIVED:
+      if ((result=recv_initial_speed())==U61_PROTOCOL_DONE)
 	{
-	  stage=INITIAL_SPEED_RECEIVED;
+	  stage=U61_CLIENTPROTOCOL_INITIAL_SPEED_RECEIVED;
 	  U61_LOG_DEBUG("stage=INITIAL_SPEED_RECEIVED");
 	}
       break;
-    case INITIAL_SPEED_RECEIVED:
-      if ((result=recv_acceleration())==DONE)
+    case U61_CLIENTPROTOCOL_INITIAL_SPEED_RECEIVED:
+      if ((result=recv_acceleration())==U61_PROTOCOL_DONE)
 	{
-	  stage=ACCELERATION_RECEIVED;
+	  stage=U61_CLIENTPROTOCOL_ACCELERATION_RECEIVED;
 	  U61_LOG_DEBUG("stage=ACCELERATION_RECEIVED");
 	}
       break;
-    case ACCELERATION_RECEIVED:
-      if ((result=recv_curse_delay())==DONE)
+    case U61_CLIENTPROTOCOL_ACCELERATION_RECEIVED:
+      if ((result=recv_curse_delay())==U61_PROTOCOL_DONE)
 	{
-	  stage=CURSE_DELAY_RECEIVED;
+	  stage=U61_CLIENTPROTOCOL_CURSE_DELAY_RECEIVED;
 	  U61_LOG_DEBUG("stage=CURSE_DELAY_RECEIVED");
 	}
       break;
-    case CURSE_DELAY_RECEIVED:
-      if ((result=recv_time())==DONE)
+    case U61_CLIENTPROTOCOL_CURSE_DELAY_RECEIVED:
+      if ((result=recv_time())==U61_PROTOCOL_DONE)
 	{
-	  stage=TIME_RECEIVED;
+	  stage=U61_CLIENTPROTOCOL_TIME_RECEIVED;
 	  U61_LOG_DEBUG("stage=TIME_RECEIVED");
 	}
       break;
-    case READY_SENT:
-      if ((result=recv_ready(connection))==DONE)
+    case U61_PROTOCOL_READY_SENT:
+      if ((result=recv_ready(connection))==U61_PROTOCOL_DONE)
 	{
-	  stage=READY_RECEIVED;
+	  stage=U61_PROTOCOL_READY_RECEIVED;
 	  U61_LOG_DEBUG("stage=READY_RECEIVED");
 	}
       break;
@@ -284,16 +299,16 @@ int U61_ClientProtocol::recv_next_packet()
  */
 int U61_ClientProtocol::start_searching()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   try 
     {
-      CL_Network::find_game_at(GAME_ID,server_id,port);
-      result=DONE;
+      CL_Network::find_game_at(U61_PROTOCOL_GAME_ID,server_id,port);
+      result=U61_PROTOCOL_DONE;
     }
   catch (CL_Error e)
     {
-      U61_LOG_WARNING("Find error : "<<e.message<<"");
+      U61_LOG_WARNING("Find error : "<<e.message.c_str()<<"");
     }
 
   return result;
@@ -306,26 +321,26 @@ int U61_ClientProtocol::start_searching()
  */
 int U61_ClientProtocol::connect_to_server()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   try 
     {
       if (CL_Network::peek_game_found())
 	{
-	  game=CL_Network::receive_game_found(TIMEOUT);
+	  game=CL_Network::receive_game_found(U61_PROTOCOL_TIMEOUT);
 	  if (game!=NULL)
 	    {
               /*
                * OK, a game has been found
                */
               join_delay_start=U61_Time::for_effect();
-	      result=DONE;
+	      result=U61_PROTOCOL_DONE;
 	    }
 	}
     }
   catch (CL_Error e)
     {
-      U61_LOG_WARNING("Connect error : "<<e.message<<"");
+      U61_LOG_WARNING("Connect error : "<<e.message.c_str()<<"");
     }
   U61_LOG_DEBUG("find server");
 
@@ -340,12 +355,12 @@ int U61_ClientProtocol::connect_to_server()
  */
 int U61_ClientProtocol::join_delay()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
-  if (U61_Time::for_effect()>join_delay_start+JOIN_DELAY)
+  if (U61_Time::for_effect()>join_delay_start+U61_CLIENTPROTOCOL_JOIN_DELAY)
     {
       channel_to_test=0;
-      result=DONE;
+      result=U61_PROTOCOL_DONE;
     }
 
   return result;
@@ -357,7 +372,7 @@ int U61_ClientProtocol::join_delay()
  */
 int U61_ClientProtocol::find_channel()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
   const CL_NetComputer *server;
 
   if (game->is_writable(channel_to_test) 
@@ -366,7 +381,7 @@ int U61_ClientProtocol::find_channel()
       server=game->get_server();
       connection=new U61_Connection(game,(CL_NetComputer *) server,
                                     channel_to_test,false);
-      result=DONE;
+      result=U61_PROTOCOL_DONE;
     }
   else
     {
@@ -383,7 +398,7 @@ int U61_ClientProtocol::find_channel()
  */
 int U61_ClientProtocol::recv_script_name()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   if (connection->peek())
     {
@@ -392,7 +407,7 @@ int U61_ClientProtocol::recv_script_name()
 	{
 	  U61_Platform::strip_remote_script_path
 	    (U61_Global::remote_script.name_buffer);
-	  result=DONE;
+	  result=U61_PROTOCOL_DONE;
           U61_LOG_DEBUG("script_name=\""<<U61_Global::remote_script.name_buffer<<"\"");
 	}
     }
@@ -408,14 +423,14 @@ int U61_ClientProtocol::recv_script_name()
  */
 int U61_ClientProtocol::recv_script()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   if (connection->peek())
     {
       if (connection->recv(U61_Global::remote_script.code_buffer,
 			   sizeof(U61_Global::remote_script.code_buffer)-1))
 	{
-	  result=DONE;
+	  result=U61_PROTOCOL_DONE;
 	}
     }
 
@@ -428,13 +443,13 @@ int U61_ClientProtocol::recv_script()
  */
 int U61_ClientProtocol::recv_id0()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   if (connection->peek())
     {
       if (connection->recv(&id0))
 	{
-	  result=DONE;
+	  result=U61_PROTOCOL_DONE;
 	  U61_LOG_DEBUG("id0="<<id0);
 	}
     }
@@ -448,13 +463,13 @@ int U61_ClientProtocol::recv_id0()
  */
 int U61_ClientProtocol::recv_id1()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   if (connection->peek())
     {
       if (connection->recv(&id1))
 	{
-	  result=DONE;
+	  result=U61_PROTOCOL_DONE;
 	  U61_LOG_DEBUG("id1="<<id1);
 	}
     }
@@ -468,13 +483,13 @@ int U61_ClientProtocol::recv_id1()
  */
 int U61_ClientProtocol::recv_initial_speed()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   if (connection->peek())
     {
       if (connection->recv(&initial_speed))
 	{
-	  result=DONE;
+	  result=U61_PROTOCOL_DONE;
 	  U61_LOG_DEBUG("initial_speed="<<initial_speed);
 	}
     }
@@ -488,13 +503,13 @@ int U61_ClientProtocol::recv_initial_speed()
  */
 int U61_ClientProtocol::recv_acceleration()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   if (connection->peek())
     {
       if (connection->recv(&acceleration))
 	{
-	  result=DONE;
+	  result=U61_PROTOCOL_DONE;
 	  U61_LOG_DEBUG("acceleration="<<acceleration);
 	}
     }
@@ -508,13 +523,13 @@ int U61_ClientProtocol::recv_acceleration()
  */
 int U61_ClientProtocol::recv_curse_delay()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   if (connection->peek())
     {
       if (connection->recv(&curse_delay))
 	{
-	  result=DONE;
+	  result=U61_PROTOCOL_DONE;
 	  U61_LOG_DEBUG("curse_delay="<<curse_delay);
 	}
     }
@@ -528,13 +543,13 @@ int U61_ClientProtocol::recv_curse_delay()
  */
 int U61_ClientProtocol::recv_time()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   if (connection->peek())
     {
       if (connection->recv(&time))
 	{
-	  result=DONE;
+	  result=U61_PROTOCOL_DONE;
 	  U61_LOG_DEBUG("time="<<time);
 	}
     }
