@@ -78,7 +78,7 @@ U61_Connection::U61_Connection(CL_NetGame *g,CL_NetComputer *c,
 	}
       catch (CL_Error e)
 	{
-	  U61_LOG_WARNING("Access error : "<<e.message<<"");
+	  U61_LOG_WARNING("Access error : "<<e.message.c_str()<<"");
 	}
     }
 }
@@ -105,9 +105,9 @@ bool U61_Connection::send(U61_Packet *p)
   if (opened)
     {
       size=p->size;
-      if (size>U61_Packet::MAX_DATA)
+      if (size>U61_PACKET_MAX_DATA)
 	{
-	  size=U61_Packet::MAX_DATA;
+	  size=U61_PACKET_MAX_DATA;
 	}
 
       CL_NetMessage message(p->data,size);
@@ -119,7 +119,7 @@ bool U61_Connection::send(U61_Packet *p)
       catch (CL_Error e)
 	{
 	  result=false;
-	  U61_LOG_WARNING("Send error : "<<e.message);
+	  U61_LOG_WARNING("Send error : "<<e.message.c_str());
 	}
     }
 
@@ -154,7 +154,7 @@ bool U61_Connection::send(char *str,int max)
       catch (CL_Error e)
 	{
 	  result=false;
-	  U61_LOG_WARNING("Send error : "<<e.message);
+	  U61_LOG_WARNING("Send error : "<<e.message.c_str());
 	}
     }
 
@@ -186,7 +186,7 @@ bool U61_Connection::send(int i)
       catch (CL_Error e)
 	{
 	  result=false;
-	  U61_LOG_WARNING("Send error : "<<e.message);
+	  U61_LOG_WARNING("Send error : "<<e.message.c_str());
 	}
     }
 
@@ -215,7 +215,7 @@ bool U61_Connection::send(U61_Event evt)
       catch (CL_Error e)
 	{
 	  result=false;
-	  U61_LOG_WARNING("Send error : "<<e.message);
+	  U61_LOG_WARNING("Send error : "<<e.message.c_str());
 	}
     }
 
@@ -254,9 +254,9 @@ bool U61_Connection::recv(U61_Packet *p)
 	  message=game->receive(channel,-1);
 
 	  size=message.data.size();
-	  if (size>U61_Packet::MAX_DATA)
+	  if (size>U61_PACKET_MAX_DATA)
 	    {
-	      size=U61_Packet::MAX_DATA;
+	      size=U61_PACKET_MAX_DATA;
 	    }
 
 	  p->size=size;
@@ -265,7 +265,7 @@ bool U61_Connection::recv(U61_Packet *p)
       catch (CL_Error e)
 	{
 	  result=false;
-	  U61_LOG_WARNING("Receive error : "<<e.message); 
+	  U61_LOG_WARNING("Receive error : "<<e.message.c_str()); 
 	}
     }
 
@@ -304,7 +304,7 @@ bool U61_Connection::recv(char *str,int max)
       catch (CL_Error e)
 	{
 	  result=false;
-	  U61_LOG_WARNING("Receive error : "<<e.message);
+	  U61_LOG_WARNING("Receive error : "<<e.message.c_str());
 	}
     }
 
@@ -346,7 +346,7 @@ bool U61_Connection::recv(int *i)
       catch (CL_Error e)
 	{
 	  result=false;
-	  U61_LOG_WARNING("Receive error : "<<e.message);
+	  U61_LOG_WARNING("Receive error : "<<e.message.c_str());
 	}
     }
 
@@ -384,7 +384,7 @@ bool U61_Connection::recv(U61_Event *evt)
       catch (CL_Error e)
 	{
 	  result=false;
-	  U61_LOG_WARNING("Receive error : "<<e.message);  
+	  U61_LOG_WARNING("Receive error : "<<e.message.c_str());  
 	}
     }
 
