@@ -40,7 +40,7 @@
  defines
  ---------------------------------------------------------------------------*/
 
-#define U61_STRING_SIZE 1000
-#define U61_SCRIPT_SIZE 1000000
+#define U61_CONST_STRING_SIZE 1000
+#define U61_CONST_SCRIPT_SIZE 1000000
 
 #endif
