@@ -91,17 +91,21 @@ void U61_Debug::flush()
  */
 void U61_Debug::log_error(ostrstream &s)
 {
-  char buffer[U61_STRING_SIZE];
+  char buffer[U61_CONST_STRING_SIZE];
   int len;
 
-  s.freeze(U61_STRING_SIZE);
+#ifndef U61_MSVC
+  s.freeze(U61_CONST_STRING_SIZE);
+#endif
   len=s.pcount();
   if (len>(int) sizeof(buffer)-1)
     {
       len=sizeof(buffer)-1;
     }
   strncpy(buffer,s.str(),len);
+#ifndef U61_MSVC
   s.freeze(0);
+#endif
 
   buffer[len]=0;
   cerr<<"U61 error: "<<buffer<<"\n";
@@ -114,17 +118,21 @@ void U61_Debug::log_error(ostrstream &s)
  */
 void U61_Debug::log_warning(ostrstream &s)
 {
-  char buffer[U61_STRING_SIZE];
+  char buffer[U61_CONST_STRING_SIZE];
   int len;
 
-  s.freeze(U61_STRING_SIZE);
+#ifndef U61_MSVC
+  s.freeze(U61_CONST_STRING_SIZE);
+#endif
   len=s.pcount();
   if (len>(int) sizeof(buffer)-1)
     {
       len=sizeof(buffer)-1;
     }
   strncpy(buffer,s.str(),len);
+#ifndef U61_MSVC
   s.freeze(0);
+#endif
 
   buffer[len]=0;
   cerr<<"U61 warning: "<<buffer<<"\n";
@@ -137,17 +145,21 @@ void U61_Debug::log_warning(ostrstream &s)
  */
 void U61_Debug::log_message(ostrstream &s)
 {
-  char buffer[U61_STRING_SIZE];
+  char buffer[U61_CONST_STRING_SIZE];
   int len;
 
-  s.freeze(U61_STRING_SIZE);
+#ifndef U61_MSVC
+  s.freeze(U61_CONST_STRING_SIZE);
+#endif
   len=s.pcount();
   if (len>(int) sizeof(buffer)-1)
     {
       len=sizeof(buffer)-1;
     }
   strncpy(buffer,s.str(),len);
+#ifndef U61_MSVC
   s.freeze(0);
+#endif
 
   buffer[len]=0;
   cout<<"U61 message: "<<buffer<<"\n";
@@ -160,17 +172,21 @@ void U61_Debug::log_message(ostrstream &s)
  */
 void U61_Debug::log_debug(ostrstream &s,char *file,int line)
 {
-  char buffer[U61_STRING_SIZE];
+  char buffer[U61_CONST_STRING_SIZE];
   int len;
 
-  s.freeze(U61_STRING_SIZE);
+#ifndef U61_MSVC
+  s.freeze(U61_CONST_STRING_SIZE);
+#endif
   len=s.pcount();
   if (len>(int) sizeof(buffer)-1)
     {
       len=sizeof(buffer)-1;
     }
   strncpy(buffer,s.str(),len);
+#ifndef U61_MSVC
   s.freeze(0);
+#endif
 
   buffer[len]=0;
   //cout<<"U61 debug: "<<buffer<<" (from "<<file<<":"<<line<<")\n";
