@@ -45,27 +45,33 @@
 #include <ClanLib/core.h>
 #include "menuitem.h"
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_EDIT_MAX_SIZE 50
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
 
 class U61_Edit: public U61_MenuItem
 {
-public:
-    U61_Edit(char *label, char *val);
+ public:
+  U61_Edit(char *label, char *val);
     
-    virtual bool action(int key);
-    virtual void update();
-    virtual void select();
-    static const int MAX_SIZE=50;
-protected:
-    char *name;
-    char *value;
-    char buffer[MAX_SIZE+1];
-    int pos;
+  virtual bool action(int key);
+  virtual void update();
+  virtual void select();
 
-    void suppress();
-    void check_pos();
+ protected:
+  char *name;
+  char *value;
+  char buffer[U61_EDIT_MAX_SIZE+1];
+  int pos;
+
+  void suppress();
+  void check_pos();
 };
 
 #endif
