@@ -47,6 +47,32 @@
  ---------------------------------------------------------------------------*/
 
 #include <ClanLib/core.h>
+#include <iostream.h>
+
+#define U61_EVENT_NOTHING            0
+
+#define U61_EVENT_START_STOP         1
+#define U61_EVENT_KILL               2
+
+#define U61_EVENT_NAME_LETTER        3
+#define U61_EVENT_CHANGE_BACKGROUND  4
+
+#define U61_EVENT_MOVE_LEFT          5
+#define U61_EVENT_MOVE_RIGHT         6
+#define U61_EVENT_ROTATE_LEFT        7
+#define U61_EVENT_ROTATE_RIGHT       8
+#define U61_EVENT_MOVE_DOWN          9
+#define U61_EVENT_DROP              10
+#define U61_EVENT_SET_VICTIM        11
+#define U61_EVENT_NEXT_VICTIM       12
+#define U61_EVENT_PREV_VICTIM       13
+#define U61_EVENT_USE_ANTIDOTE      14
+ 
+#define U61_EVENT_NEW_BLOCK         15
+#define U61_EVENT_LOOSE             16
+#define U61_EVENT_NEW_CURSE         17
+#define U61_EVENT_REQUEST_CURSE     18
+#define U61_EVENT_DO_CURSE          19
 
 /*---------------------------------------------------------------------------
  classes
@@ -58,29 +84,6 @@ class U61_Event
   U61_Event();
   ~U61_Event();
  
-  enum 
-  { 
-    NOTHING,
-
-    START_STOP,
-    KILL,
-
-    NAME_LETTER,
-    CHANGE_BACKGROUND,
-
-    MOVE_LEFT, MOVE_RIGHT,
-    ROTATE_LEFT, ROTATE_RIGHT,
-    MOVE_DOWN, DROP,
-    SET_VICTIM,NEXT_VICTIM,PREV_VICTIM,
-    USE_ANTIDOTE,
- 
-    NEW_BLOCK,
-    LOOSE,
-    NEW_CURSE,
-    REQUEST_CURSE,
-    DO_CURSE
-  };  
-
   unsigned int code : 8;
   unsigned int author : 4;
   unsigned int target : 4;
