@@ -106,9 +106,9 @@ U61_FileMenu::U61_FileMenu(U61_Menu *parent, char *top,
 bool U61_FileMenu::add_files(char *dir)
 {
   char *name;
-  char buffer_label[U61_STRING_SIZE];
-  char buffer_name[U61_STRING_SIZE];
-  char last_chosen_file[U61_STRING_SIZE];
+  char buffer_label[U61_CONST_STRING_SIZE];
+  char buffer_name[U61_CONST_STRING_SIZE];
+  char last_chosen_file[U61_CONST_STRING_SIZE];
   bool exists=false;
 
   strcpy(last_chosen_file,chosen_file);
