@@ -64,9 +64,16 @@
 #include "debug.h"
 
 /*---------------------------------------------------------------------------
- globals
+ constants
  ---------------------------------------------------------------------------*/
- 
+
+#define U61_GAME_MAX_LOGIC_PER_DISPLAY 1000
+#define U61_GAME_LIMIT_LOGIC_PER_DISPLAY 100
+#define U61_GAME_MENU_POLL_DELAY 33
+
+#define U61_GAME_STATE_RUN               0
+#define U61_GAME_STATE_QUIT              1
+
 
 /*---------------------------------------------------------------------------
  functions
@@ -118,9 +125,9 @@ bool U61_Game::init(char *filename)
   dispatcher=NULL;
 
   strcpy(exe_name,filename);
-
+  
   U61_Global::config.read();
-    
+  
   U61_Script::init();
 
   if (success)
@@ -133,7 +140,7 @@ bool U61_Game::init(char *filename)
     {
       success=success && 
 	U61_Utils::set_videomode(U61_Global::data.screen_w,
-			 	 U61_Global::data.screen_h,
+				 U61_Global::data.screen_h,
 				 U61_Global::config.fullscreen);
     }
 
@@ -141,7 +148,7 @@ bool U61_Game::init(char *filename)
     {
       success=success && U61_Global::data.load2();
     }  
-
+      
   if (success)
     {
       U61_Global::input_monitor.init();
@@ -172,7 +179,7 @@ void U61_Game::run()
   bool last_display_too_slow;
   U61_Menu *exit_menu;
 
-  state=STATE_RUN;
+  state=U61_GAME_STATE_RUN;
   slow_down_allowed=true;
   last_display_too_slow=false;
     
@@ -209,7 +216,7 @@ void U61_Game::run()
   /*
    * main game loop
    */
-  while (state==STATE_RUN) 
+  while (state==U61_GAME_STATE_RUN) 
     {
       /*
        * we perform calls to the logic function, but we don't
@@ -219,7 +226,7 @@ void U61_Game::run()
        */
       done_for_this_display=0;
       while (U61_Time::is_logic_needed() 
-	     && done_for_this_display < MAX_LOGIC_PER_DISPLAY)
+	     && done_for_this_display < U61_GAME_MAX_LOGIC_PER_DISPLAY)
         {
 	  poll();
 	  logic();
@@ -233,7 +240,7 @@ void U61_Game::run()
        * force the computer to slow down the game, since it's
        * not powerfull enough to run it at full speed
        */
-      if (done_for_this_display>LIMIT_LOGIC_PER_DISPLAY)
+      if (done_for_this_display>U61_GAME_LIMIT_LOGIC_PER_DISPLAY)
         {
 	  /*
 	   * We display a warning message if display is slow twice in a row
@@ -287,7 +294,7 @@ void U61_Game::run()
  */
 void U61_Game::quit()
 {
-  state=STATE_QUIT;
+  state=U61_GAME_STATE_QUIT;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -331,7 +338,7 @@ void U61_Game::poll()
         {
 	  last_u61_time_polled=u61_time;   
 
-	  for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL;++i)
+	  for (i=0;i<U61_LAYOUT_NB_PLAYERS_LOCAL;++i)
             {
 	      player_input[i].poll(u61_time);
             }
@@ -342,7 +349,7 @@ void U61_Game::poll()
        * this test disables useless polling
        * polling is done at a maximum rate of 30 / sec
        */
-      if (last_menu_time_polled<clanlib_time-MENU_POLL_DELAY)
+      if (last_menu_time_polled<clanlib_time-U61_GAME_MENU_POLL_DELAY)
         {
 	  last_menu_time_polled=clanlib_time;   
 
@@ -378,18 +385,8 @@ void U61_Game::logic()
  */ 
 void U61_Game::display()
 {
-  CL_Display::clear_display();
-
   U61_Square::update_cycle();
-  /*
-    for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
-    {
-    if (player[i].is_available())
-    {
-    player[i].draw(0,0);
-    }
-    }
-  */   
+
   U61_Global::layout.draw();
   if (current_menu!=NULL)
     {
@@ -472,8 +469,8 @@ void U61_Game::network()
 
   if (protocol!=NULL)
     {
-      if (protocol->send_all()==U61_Protocol::FAILED 
-	  || protocol->recv_all()==U61_Protocol::FAILED)
+      if (protocol->send_all()==U61_PROTOCOL_FAILED 
+	  || protocol->recv_all()==U61_PROTOCOL_FAILED)
 	{
 	  protocol->print_diagnostic();
 	}
@@ -482,7 +479,7 @@ void U61_Game::network()
   if (dispatcher!=NULL)
     {
       dispatcher->process();
-      for (i=0;i<U61_Dispatcher::MAX_PLAYER_ID;++i)
+      for (i=0;i<U61_DISPATCHER_MAX_PLAYER_ID;++i)
 	{
           if (dispatcher->is_player_busy(i) && !exists_player_id(i))
 	    {
@@ -550,7 +547,7 @@ void U61_Game::configure_hot()
   int i;
 
   bind_keys();
-  for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL;++i)
+  for (i=0;i<U61_LAYOUT_NB_PLAYERS_LOCAL;++i)
     {
     } 
 }
@@ -690,7 +687,7 @@ void U61_Game::start_network_new()
         {
 	  U61_Global::layout.init_network_1
 	    (&(player[0]),
-	     &(player[U61_Layout::NB_PLAYERS_NET_LOCAL]));
+	     &(player[U61_LAYOUT_NB_PLAYERS_NET_LOCAL]));
         }
       else
         {
@@ -702,7 +699,7 @@ void U61_Game::start_network_new()
 	  U61_Global::layout.init_network_2
 	    (&(player[0]),
 	     &(player[1]),
-	     &(player[U61_Layout::NB_PLAYERS_NET_LOCAL]));
+	     &(player[U61_LAYOUT_NB_PLAYERS_NET_LOCAL]));
 	}
     }
 
@@ -761,7 +758,7 @@ void U61_Game::do_network_join(char *script,
     {
       U61_Global::layout.init_network_1
 	(&(player[0]),
-	 &(player[U61_Layout::NB_PLAYERS_NET_LOCAL]));
+	 &(player[U61_LAYOUT_NB_PLAYERS_NET_LOCAL]));
     }
   else
     {
@@ -773,7 +770,7 @@ void U61_Game::do_network_join(char *script,
       U61_Global::layout.init_network_2
 	(&(player[0]),
 	 &(player[1]),
-	 &(player[U61_Layout::NB_PLAYERS_NET_LOCAL]));
+	 &(player[U61_LAYOUT_NB_PLAYERS_NET_LOCAL]));
     }
 
   U61_Music::start();
@@ -805,7 +802,7 @@ void U61_Game::stop()
 {
   int i;
 
-  for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
+  for (i=0;i<U61_LAYOUT_NB_PLAYERS_TOTAL;++i)
     {
       player[i].kill();
     }
@@ -813,6 +810,7 @@ void U61_Game::stop()
   U61_Global::layout.reset();
   stop_network();
   U61_Time::resume();
+  U61_Music::stop();
 
   U61_Platform::close_score_file();
 
@@ -854,7 +852,7 @@ void U61_Game::time_reset(int time)
   U61_Time::reset(time);
   last_u61_time_polled=time;
   menu_input.reset();
-  for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL;++i)
+  for (i=0;i<U61_LAYOUT_NB_PLAYERS_LOCAL;++i)
     {
       player_input[i].reset();
     }    
@@ -869,7 +867,7 @@ void U61_Game::bind_keys()
 {
   int i;
 
-  for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL && i<U61_Config::NB_PLAYERS;++i)
+  for (i=0;i<U61_LAYOUT_NB_PLAYERS_LOCAL && i<U61_CONFIG_NB_PLAYERS;++i)
     {
       player_input[i].init(&(U61_Global::config.player[i]));
     }
@@ -883,7 +881,7 @@ void U61_Game::reset_players()
 {
   int i;
 
-  for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
+  for (i=0;i<U61_LAYOUT_NB_PLAYERS_TOTAL;++i)
     {
       player[i].reset();
       player[i].set_id(i);
@@ -899,7 +897,7 @@ void U61_Game::pump_player_events()
 {
   int i;
 
-  for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
+  for (i=0;i<U61_LAYOUT_NB_PLAYERS_TOTAL;++i)
     {
       if (player[i].is_available())
         {
@@ -921,7 +919,7 @@ int U61_Game::get_local_player(int order)
   int found=0;
   int i;
 
-  for (i=0;i<U61_Config::NB_PLAYERS;++i)
+  for (i=0;i<U61_CONFIG_NB_PLAYERS;++i)
     {
       if (U61_Global::config.player[i].activable)
         {
@@ -969,7 +967,7 @@ int U61_Game::find_free_player_id(int start,int step)
   int result=-1;
   bool taken;
 
-  for (i=start;i<=U61_Dispatcher::MAX_PLAYER_ID-step;i+=step)
+  for (i=start;i<=U61_DISPATCHER_MAX_PLAYER_ID-step;i+=step)
     {
       taken=false;
       for (j=0;j<step;++j)
@@ -999,8 +997,8 @@ int U61_Game::find_free_network_slot()
   int i;
   int result=-1;
 
-  for (i=U61_Layout::NB_PLAYERS_NET_LOCAL;
-       i<U61_Layout::NB_PLAYERS_TOTAL;
+  for (i=U61_LAYOUT_NB_PLAYERS_NET_LOCAL;
+       i<U61_LAYOUT_NB_PLAYERS_TOTAL;
        ++i)
     {
       if (!player[i].is_available())
@@ -1021,7 +1019,7 @@ bool U61_Game::exists_player_id(int player_id)
   bool result=false;
   int i;
 
-  for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
+  for (i=0;i<U61_LAYOUT_NB_PLAYERS_TOTAL;++i)
     {
       if (player[i].is_available() && player[i].get_id()==player_id)
 	{
@@ -1047,7 +1045,7 @@ U61_Player *U61_Game::find_player_by_id(int id)
   U61_Player *result=NULL;
   int i;
 
-  for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
+  for (i=0;i<U61_LAYOUT_NB_PLAYERS_TOTAL;++i)
     {
       if (player[i].is_available() && player[i].get_id()==id)
 	{
