@@ -122,18 +122,18 @@ void U61_Key::poll(int time)
     {
       switch (state)
 	{
-        case RELEASED:
-	  state=PRESSED;
+        case U61_KEY_RELEASED:
+	  state=U61_KEY_PRESSED;
 	  fire(time);
 	  break;
-        case PRESSED:
+        case U61_KEY_PRESSED:
 	  if (time-last_fired>first_delay)
 	    {
-	      state=REPEATING;
+	      state=U61_KEY_REPEATING;
 	      fire(last_fired+first_delay);
 	    }
 	  break;
-        case REPEATING:
+        case U61_KEY_REPEATING:
 	  while (time-last_fired>standard_delay)
 	    {
 	      fire(last_fired+standard_delay);
@@ -143,7 +143,7 @@ void U61_Key::poll(int time)
     }
   else
     {
-      state=RELEASED;
+      state=U61_KEY_RELEASED;
       last_fired=0;
     } 
 }
@@ -155,7 +155,7 @@ void U61_Key::poll(int time)
 void U61_Key::reset()
 {
   last_fired=0;
-  state=RELEASED;
+  state=U61_KEY_RELEASED;
 }
 
 /*--------------------------------------------------------------------------*/
