@@ -47,6 +47,16 @@
 
 #include "event.h"
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_KEY_RELEASED   0
+#define U61_KEY_PRESSED    1
+#define U61_KEY_REPEATING  2
+
+#define U61_KEY_NO_REPEAT 999999999
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -55,9 +65,9 @@ class U61_Key
 { 
 public:
     U61_Key(int key_code_in=CL_KEY_ESCAPE, 
-            int evt_code_out=U61_Event::NOTHING,
-            int first_repeat_delay=NO_REPEAT,
-            int standard_repeat_delay=NO_REPEAT);
+            int evt_code_out=U61_EVENT_NOTHING,
+            int first_repeat_delay=U61_KEY_NO_REPEAT,
+            int standard_repeat_delay=U61_KEY_NO_REPEAT);
     ~U61_Key();
 
     void init(int key_code_in,
@@ -72,16 +82,8 @@ public:
     int get_code_in();    
     int get_code_out();    
 
-    enum
-    {
-        RELEASED,
-        PRESSED,
-        REPEATING
-    };
-
-    static const int NO_REPEAT=999999999;
 protected:
-    list<U61_Event> queue;
+    std::list<U61_Event> queue;
  
     int code_in;
     int code_out;
