@@ -45,9 +45,12 @@
 #include "global.h"
 
 /*---------------------------------------------------------------------------
- variants
+ constants
  ---------------------------------------------------------------------------*/
 
+#define U61_LAYOUTITEM_LIMIT_CURSE       4
+#define U61_LAYOUTITEM_LIMIT_ANTIDOTE    4
+
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
@@ -78,6 +81,7 @@ void U61_LayoutItem::reset()
 {
   active=false;
   bg_changed=true;
+  last_background=-1;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -135,13 +139,18 @@ bool U61_LayoutItem::is_player_available()
  */
 void U61_LayoutItem::calc_coords()
 {
-  int total_y;
+  /*
+   * There used to be many calculus here, but now all the values are
+   * hard coded in the datafiles. The function has been kept however,
+   * for it does no harm and could be used later
+   */
+  x_corner=x_center-U61_Global::data.player_w[size]/2;
+  y_corner=y_center-U61_Global::data.player_h[size]/2;
 
-  total_y=U61_Global::data.map_h[size]+U61_Global::data.info_h[size];
-  x_map=x_center-U61_Global::data.map_w[size]/2;
-  y_map=y_center-total_y/2;
-  x_info=x_center-U61_Global::data.info_w[size]/2;
-  y_info=y_map+U61_Global::data.map_h[size];
+  x_map=x_corner+U61_Global::data.offset_map_x[size];
+  y_map=y_corner+U61_Global::data.offset_map_y[size];
+  x_info=x_corner+U61_Global::data.offset_info_x[size];
+  y_info=y_corner+U61_Global::data.offset_info_y[size];
 }
 
 /*--------------------------------------------------------------------------*/
@@ -150,18 +159,57 @@ void U61_LayoutItem::calc_coords()
  */
 bool U61_LayoutItem::has_background_changed()
 {
+  int background;
+
+  if (active && player->is_available())
+    {
+      background=player->get_background();
+      if (background!=last_background)
+	{
+	  bg_changed=true;
+	  last_background=background;
+	}
+    }
+
   return bg_changed;
 }
 
 /*--------------------------------------------------------------------------*/
 /*
- * draws the backgounds onto a specific bitmap
+ * draws the background of the map directly on the screen
  */
-void U61_LayoutItem::draw_background(CL_Canvas *target)
+void U61_LayoutItem::draw_back_screen()
 {
-  if (active)
+  int background;
+
+  if (active && player->is_available())
     {
-    } 
+      //      U61_Global::data.info[size]->convert_video();
+      U61_Global::data.info[size]->put_screen(x_info,y_info);
+
+      background=player->get_background();
+      //      U61_Global::data.map[background][size]->convert_video();
+      U61_Global::data.map[background][size]->put_screen(x_map,y_map);
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * draws the background of the map on a temporary target
+ */
+void U61_LayoutItem::draw_back(CL_Target *target)
+{
+  int background;
+
+  if (active && player->is_available())
+    {
+      //      U61_Global::data.info[size]->convert_system();
+      U61_Global::data.info[size]->put_target(x_info,y_info,0,target);
+
+      background=player->get_background();
+      //      U61_Global::data.map[background][size]->convert_system();
+      U61_Global::data.map[background][size]->put_target(x_map,y_map,0,target);
+    }
 }
 
 /*--------------------------------------------------------------------------*/
@@ -170,15 +218,21 @@ void U61_LayoutItem::draw_background(CL_Canvas *target)
  */
 void U61_LayoutItem::draw()
 {
-  char buffer[U61_STRING_SIZE];
+  char buffer[U61_CONST_STRING_SIZE];
   U61_Player *target;
   int i=0;
 
+  /*
+   * Now se set the layoutitem to "unchanged" since it has been drawn at least
+   * once. To put it in "changed" state again one will have to call reset
+   * or init.
+   */
+  bg_changed=false;
+
   if (active && player->is_available())
     {
-      player->draw(x_map,y_map,size);
-
-      U61_Global::data.info[size]->put_screen(x_info,y_info);
+      player->draw(x_map+U61_Global::data.offset_squares_x[size],
+		   y_map+U61_Global::data.offset_squares_y[size],size);
 
       sprintf(buffer,"%s",player->get_name());
       buffer[6]=0;
@@ -189,7 +243,7 @@ void U61_LayoutItem::draw()
 
       if (player->is_active())
 	{
-	  sprintf(buffer,"%6d",player->get_score()/U61_Score::SCORE_DIVIDER);
+	  sprintf(buffer,"%6d",player->get_score()/U61_SCORE_SCORE_DIVIDER);
 	  U61_Global::data.font_info[size]->print_left
 	    (x_info+U61_Global::data.offset_score_x[size],
 	     y_info+U61_Global::data.offset_score_y[size],
@@ -212,9 +266,9 @@ void U61_LayoutItem::draw()
 	    }
 
 	  buffer[0]=0;
-	  while (i<4 && i<player->get_nb_curse())
+	  while (i<U61_LAYOUTITEM_LIMIT_CURSE && i<player->get_nb_curse())
 	    {
-	      strcat(buffer,U61_Data::SYMBOL_CURSE);
+	      strcat(buffer,U61_DATA_SYMBOL_CURSE);
 	      ++i;
 	    }
 	  U61_Global::data.font_symbol[size]->print_left
@@ -223,9 +277,9 @@ void U61_LayoutItem::draw()
 	     buffer);
 
 	  buffer[0]=0;
-	  while (i<4 && i<player->get_nb_antidote())
+	  while (i<U61_LAYOUTITEM_LIMIT_ANTIDOTE && i<player->get_nb_antidote())
 	    {
-	      strcat(buffer,U61_Data::SYMBOL_ANTIDOTE);
+	      strcat(buffer,U61_DATA_SYMBOL_ANTIDOTE);
 	      ++i;
 	    }
 	  U61_Global::data.font_symbol[size]->print_left
