@@ -48,6 +48,10 @@
  globals
  ---------------------------------------------------------------------------*/
 
+#define U61_LETTER_W_MAX_MOVE 2
+#define U61_LETTER_H_MAX_MOVE 3
+
+#define U61_LETTER_SLOW_FACTOR 5
 
 /*---------------------------------------------------------------------------
  functions
@@ -137,20 +141,20 @@ void U61_Letter::compute()
       dx+=vx;
       dy+=vy;
         
-      if (dx<-W_MAX_MOVE||dx>W_MAX_MOVE)
+      if (dx<-U61_LETTER_W_MAX_MOVE||dx>U61_LETTER_W_MAX_MOVE)
         {
 	  dx-=vx;
 	  change_vx();
 	  //            change_vy();
         }
-      if (dy<-H_MAX_MOVE||dy>H_MAX_MOVE)
+      if (dy<-U61_LETTER_H_MAX_MOVE||dy>U61_LETTER_H_MAX_MOVE)
         {
 	  dy-=vy;
 	  change_vy();
 	  //            change_vx();
         }
 
-      last_time+=SLOW_FACTOR;
+      last_time+=U61_LETTER_SLOW_FACTOR;
     }    
 }
 
@@ -192,7 +196,7 @@ void U61_Letter::change_vy()
  */
 void U61_Letter::change_dx()
 {
-  dx=U61_Utils::random(W_MAX_MOVE)-W_MAX_MOVE/2;
+  dx=U61_Utils::random(U61_LETTER_W_MAX_MOVE)-U61_LETTER_W_MAX_MOVE/2;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -201,7 +205,7 @@ void U61_Letter::change_dx()
  */
 void U61_Letter::change_dy()
 {
-  dy=U61_Utils::random(H_MAX_MOVE)-H_MAX_MOVE/2;
+  dy=U61_Utils::random(U61_LETTER_H_MAX_MOVE)-U61_LETTER_H_MAX_MOVE/2;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -269,7 +273,7 @@ int U61_Letter::get_height()
   height=font->get_height();
   if (dance_state)
     {
-      height+=H_MAX_MOVE;
+      height+=U61_LETTER_H_MAX_MOVE;
     }
   return height;
 }
@@ -289,7 +293,7 @@ int U61_Letter::get_width()
   width=font->get_text_width(text);
   if (dance_state)
     {
-      width+=W_MAX_MOVE;
+      width+=U61_LETTER_W_MAX_MOVE;
     }
   return width;
 }
