@@ -76,11 +76,6 @@ protected:
     int vx;
     int vy;
  
-    static const int W_MAX_MOVE=2;
-    static const int H_MAX_MOVE=3;
-
-    static const int SLOW_FACTOR=5;
- 
     void compute();
     void change_vx();
     void change_vy();
