@@ -51,6 +51,7 @@
 #include "sound.h"
 #include "utils.h"
 #include "debug.h"
+#include "music.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -61,7 +62,7 @@
  * these arrays contain constants used for speeds, this way one can
  * have something more subtle than just a linear behavior
  */ 
-const int U61_Map::speeds[MAX_SYSTEM_SPEED+1]=
+static int speeds[U61_MAP_MAX_SYSTEM_SPEED+1]=
 {
   1,  2,  5,  10, 20, 30, 40, 50, 60, 70, 80,
   84, 88, 92, 96, 100,104,108,112,116,120,
@@ -69,7 +70,8 @@ const int U61_Map::speeds[MAX_SYSTEM_SPEED+1]=
   164,168,172,176,180,184,188,192,196,200,
   210,220,240,260,280,300,350,400,450,500
 };
-const int U61_Map::accels[MAX_SYSTEM_ACCEL+1]=
+
+static int accels[U61_MAP_MAX_SYSTEM_ACCEL+1]=
 {
   0,  10, 20, 30, 40, 50,
   60, 80, 100,140,200,
@@ -106,9 +108,9 @@ void U61_Map::clear()
 {
   int i,j;
 
-  for (j=0;j<HEIGHT;++j)
+  for (j=0;j<U61_MAP_HEIGHT;++j)
     {
-      for (i=0;i<WIDTH;++i)
+      for (i=0;i<U61_MAP_WIDTH;++i)
         {
 	  squares[i][j].disable();
 	  //squares[i][j].enable();
@@ -158,17 +160,17 @@ void U61_Map::begin()
   curse_sent=0;
   curse_received=0;
   start_time=0;
-  for (i=0;i<NB_GLOBAL;++i)
+  for (i=0;i<U61_MAP_NB_GLOBAL;++i)
     {
       global_val[i]=0;
     }        
-  for (i=0;i<MAX_CURSE_ID;++i)
+  for (i=0;i<U61_MAP_MAX_CURSE_ID;++i)
     {
       curse_begin[i]=-1;
     }        
   change_background();
 
-  evt.code=U61_Event::SET_VICTIM;
+  evt.code=U61_EVENT_SET_VICTIM;
   evt.par=target_id;
   put_auto_event(evt);
 }
@@ -262,9 +264,9 @@ int U61_Map::get_background()
  */
 void U61_Map::set_square_color(int x,int y,int color)
 {
-  if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
+  if (x>=0 && y>=0 && x<U61_MAP_WIDTH && y<U61_MAP_HEIGHT)
     {
-      if (color>=0 && color<U61_Square::NB_COLORS)
+      if (color>=0 && color<U61_SQUARE_NB_COLORS)
         {
 	  squares[x][y].enable();
 	  squares[x][y].set_color(color);
@@ -287,7 +289,7 @@ int U61_Map::get_square_color(int x,int y)
 {
   int color=-1;
 
-  if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
+  if (x>=0 && y>=0 && x<U61_MAP_WIDTH && y<U61_MAP_HEIGHT)
     {
       if (squares[x][y].is_enabled())
         {
@@ -305,13 +307,13 @@ void U61_Map::set_score(int s)
 {
   if (s>=0)
     {
-      if (s<MAX_SCORE)
+      if (s<U61_MAP_MAX_SCORE)
 	{
           score=s;
 	}
       else
         {
-	  score=MAX_SCORE-1;
+	  score=U61_MAP_MAX_SCORE-1;
 	}
     }
   else
@@ -405,7 +407,7 @@ int U61_Map::get_match_count()
  */
 void U61_Map::set_global(int i, int glob)
 {
-  if (i>=0 && i<NB_GLOBAL)
+  if (i>=0 && i<U61_MAP_NB_GLOBAL)
     {
       global_val[i]=glob;
     }
@@ -420,7 +422,7 @@ int U61_Map::get_global(int i)
 {
   int glob=0;
 
-  if (i>=0 && i<NB_GLOBAL)
+  if (i>=0 && i<U61_MAP_NB_GLOBAL)
     {
       glob=global_val[i];
     }
@@ -437,7 +439,7 @@ int U61_Map::get_curse_age(int i)
 {
   int age=false;
 
-  if (i>=0 && i<MAX_CURSE_ID)
+  if (i>=0 && i<U61_MAP_MAX_CURSE_ID)
     {
       if (curse_begin[i]<0 || map_time>curse_end[i])
 	{
@@ -445,7 +447,7 @@ int U61_Map::get_curse_age(int i)
 	}
       else
 	{
-          age=((map_time-curse_begin[i])/U61_Time::ONE_SECOND);
+          age=((map_time-curse_begin[i])/U61_TIME_ONE_SECOND);
 	}
     }
 
@@ -459,7 +461,7 @@ int U61_Map::get_curse_age(int i)
  */
 void U61_Map::register_curse(int i, int length)
 {
-  if (i>=0 && i<MAX_CURSE_ID)
+  if (i>=0 && i<U61_MAP_MAX_CURSE_ID)
     {
       /*
        * if length is zero, the default length is 10 hours
@@ -470,7 +472,7 @@ void U61_Map::register_curse(int i, int length)
 	  length=36000;
 	}
       curse_begin[i]=map_time;
-      curse_end[i]=map_time+length*U61_Time::ONE_SECOND;
+      curse_end[i]=map_time+length*U61_TIME_ONE_SECOND;
       U61_LOG_DEBUG("Registering "<<i<<" begin="<<curse_begin[i]<<" end="<<curse_end[i]);
     }
 }
@@ -481,7 +483,7 @@ void U61_Map::register_curse(int i, int length)
  */
 void U61_Map::cancel_curse(int i)
 {
-  if (i>=0 && i<MAX_CURSE_ID)
+  if (i>=0 && i<U61_MAP_MAX_CURSE_ID)
     {
       curse_begin[i]=-1;
     }
@@ -500,7 +502,7 @@ int U61_Map::get_oldest_curse()
 
   oldest=map_time;
   
-  for (i=0;i<MAX_CURSE_ID;++i)
+  for (i=0;i<U61_MAP_MAX_CURSE_ID;++i)
     {
       if (get_curse_age(i)>=0 &&
 	  curse_begin[i]<=map_time)
@@ -523,7 +525,7 @@ int U61_Map::get_nb_curse()
   int i;
 
   nb=0;
-  for (i=0;i<MAX_CURSE_ID;++i)
+  for (i=0;i<U61_MAP_MAX_CURSE_ID;++i)
     {
       if (get_curse_age(i)>=0)
 	{
@@ -569,7 +571,7 @@ void U61_Map::delete_antidote()
  */
 void U61_Map::set_curse_x(int x)
 {
-  if (x>=0 && x<WIDTH)
+  if (x>=0 && x<U61_MAP_WIDTH)
     {
       curse_x=x;
     }
@@ -581,7 +583,7 @@ void U61_Map::set_curse_x(int x)
  */
 void U61_Map::set_curse_y(int y)
 {
-  if (y>=0 && y<HEIGHT)
+  if (y>=0 && y<U61_MAP_HEIGHT)
     {
       curse_y=y;
     }
@@ -654,7 +656,7 @@ bool U61_Map::is_curse_available()
 {
   bool result=false;
 
-  if (curse_x>=0 && curse_y>=0 && curse_x<WIDTH && curse_y<HEIGHT
+  if (curse_x>=0 && curse_y>=0 && curse_x<U61_MAP_WIDTH && curse_y<U61_MAP_HEIGHT
       && curse_state && curse_chosen
       && squares[curse_x][curse_y].is_enabled())
     {
@@ -674,12 +676,12 @@ void U61_Map::send_curse(int curse_id)
 {
   U61_Event evt;
 
-  if (player_id!=target_id && curse_id>=0 && curse_id<MAX_CURSE_ID)
+  if (player_id!=target_id && curse_id>=0 && curse_id<U61_MAP_MAX_CURSE_ID)
     {
       U61_LOG_DEBUG("Sending curse "<<curse_id);
 
       curse_sent++;
-      evt.code=U61_Event::REQUEST_CURSE;
+      evt.code=U61_EVENT_REQUEST_CURSE;
       evt.par=curse_id;
       /*
        * We use put_request_event instead of calling put_auto_event
@@ -718,15 +720,15 @@ void U61_Map::compute_next()
   map_time++;
   curse_counter++;
   update_explosions();
-  if (!(map_time%TIME_CALLBACK_DELAY))
+  if (!(map_time%U61_MAP_TIME_CALLBACK_DELAY))
     {
       time_callback();
     }
-  if (!(map_time%CHECK_TARGET_DELAY))
+  if (!(map_time%U61_MAP_CHECK_TARGET_DELAY))
     {
       check_target();
     }
-  if (!(map_time%CHECK_CURSE_DELAY))
+  if (!(map_time%U61_MAP_CHECK_CURSE_DELAY))
     {
       check_curse();
     }
@@ -748,15 +750,15 @@ void U61_Map::update_speed()
   check_accel();
 
   speed_counter+=speeds[speed];
-  if (speed_counter>SPEED_SCALE)
+  if (speed_counter>U61_MAP_SPEED_SCALE)
     {
-      speed_counter-=SPEED_SCALE;
+      speed_counter-=U61_MAP_SPEED_SCALE;
       block_move_down(); 
     }    
   accel_counter+=accels[accel];
-  if (accel_counter>ACCEL_SCALE)
+  if (accel_counter>U61_MAP_ACCEL_SCALE)
     {
-      accel_counter-=ACCEL_SCALE;
+      accel_counter-=U61_MAP_ACCEL_SCALE;
       speed++;
       U61_LOG_DEBUG("Next speed ("<<speed);
     }    
@@ -801,52 +803,52 @@ void U61_Map::handle_event(U61_Event *event)
 	  compute_up_to(event->time);
 	  switch (event->code)
             {
-            case U61_Event::ROTATE_LEFT:
+            case U61_EVENT_ROTATE_LEFT:
 	      block_rotate_left();
 	      break;
-            case U61_Event::ROTATE_RIGHT:
+            case U61_EVENT_ROTATE_RIGHT:
 	      block_rotate_right();
 	      break;
-            case U61_Event::MOVE_RIGHT:
+            case U61_EVENT_MOVE_RIGHT:
 	      block_move_right();
 	      break;
-            case U61_Event::MOVE_LEFT:
+            case U61_EVENT_MOVE_LEFT:
 	      block_move_left();
 	      break;
-            case U61_Event::MOVE_DOWN:
+            case U61_EVENT_MOVE_DOWN:
 	      block_move_down();
 	      break;
-            case U61_Event::DROP:
+            case U61_EVENT_DROP:
 	      block_drop();
 	      break;
-            case U61_Event::NEW_BLOCK:
+            case U61_EVENT_NEW_BLOCK:
 	      new_block(event->par);
 	      break;
-            case U61_Event::LOOSE:
+            case U61_EVENT_LOOSE:
 	      loose();
 	      break;
-            case U61_Event::PREV_VICTIM:
+            case U61_EVENT_PREV_VICTIM:
               prev_victim(event);
               break;
-            case U61_Event::NEXT_VICTIM:
+            case U61_EVENT_NEXT_VICTIM:
               next_victim(event);
               break;
-            case U61_Event::SET_VICTIM:
+            case U61_EVENT_SET_VICTIM:
               set_victim(event->par);
               break;
-            case U61_Event::NAME_LETTER:
+            case U61_EVENT_NAME_LETTER:
               name_add_letter(event->par);
 	      break;
-            case U61_Event::NEW_CURSE:
+            case U61_EVENT_NEW_CURSE:
               new_curse(event->par);
 	      break;
-            case U61_Event::REQUEST_CURSE:
+            case U61_EVENT_REQUEST_CURSE:
               request_curse(*event);
 	      break;
-            case U61_Event::DO_CURSE:
+            case U61_EVENT_DO_CURSE:
               do_curse(*event);
 	      break;
-            case U61_Event::USE_ANTIDOTE:
+            case U61_EVENT_USE_ANTIDOTE:
               use_antidote();
               break;
             }
@@ -877,9 +879,9 @@ void U61_Map::anticipate(int time)
    * that fake events are sent 10 times/sec on local players
    * and 1 time/sec for remote players
    */
-  if (time-map_time>ANTICIPATE_MAX)
+  if (time-map_time>U61_MAP_ANTICIPATE_MAX)
     {
-      time=map_time+ANTICIPATE_MAX;
+      time=map_time+U61_MAP_ANTICIPATE_MAX;
     }
   compute_up_to(time);
   auto_events.clear();
@@ -901,7 +903,7 @@ void U61_Map::poll_auto_events()
 	  && (!matching))
         {
 	  block_requested=true;
-	  event.code=U61_Event::NEW_BLOCK;
+	  event.code=U61_EVENT_NEW_BLOCK;
 	  event.par=U61_Script::new_shape(this,&block);
 	  put_auto_event(event);
 	  U61_LOG_DEBUG("new block event sent");
@@ -913,7 +915,7 @@ void U61_Map::poll_auto_events()
 	{
 	  curse_asked=true;
 	  curse_counter=0;
-          event.code=U61_Event::NEW_CURSE;
+          event.code=U61_EVENT_NEW_CURSE;
           event.par=U61_Script::new_curse(this,&block);
           put_auto_event(event);
           U61_LOG_DEBUG("Auto curse event "<<event.par);
@@ -1005,26 +1007,17 @@ char *U61_Map::get_name()
 void U61_Map::draw(int x,int y, int size, bool anti)
 {
   int i,j;
-  int x_square_offset;
-  int y_square_offset;
   int draw_x,draw_y;
 
   if (active)
     {
-      x_square_offset=U61_Global::data.offset_map_x[size]+x;
-      y_square_offset=U61_Global::data.offset_map_y[size]+y;
-
-      U61_Global::data.map[background][size]->put_screen(x,y);
-
-      for (j=0;j<HEIGHT;++j)
+      for (j=0;j<U61_MAP_HEIGHT;++j)
         {
-	  for (i=0;i<WIDTH;++i)
+	  for (i=0;i<U61_MAP_WIDTH;++i)
             {
-	      draw_x=x_square_offset
-		+i*U61_Global::data.square_w[size];
+	      draw_x=x+i*U61_Global::data.square_w[size];
 
-	      draw_y=y_square_offset
-		+j*U61_Global::data.square_h[size];
+	      draw_y=y+j*U61_Global::data.square_h[size];
 
               if (j==curse_y && i==curse_x && 
 		  curse_state && curse_chosen &&
@@ -1047,9 +1040,9 @@ void U61_Map::draw(int x,int y, int size, bool anti)
         }
       if (anticipation_state && anti)
         {
-	  draw_anticipation(x_square_offset,y_square_offset,size);
+	  draw_anticipation(x,y,size);
         }
-      block.draw(x_square_offset,y_square_offset,size);
+      block.draw(x,y,size);
     }
 }
 
@@ -1123,9 +1116,9 @@ int U61_Map::get_speed()
  */
 void U61_Map::check_speed()
 {
-  if (speed>MAX_SYSTEM_SPEED)
+  if (speed>U61_MAP_MAX_SYSTEM_SPEED)
     {
-      speed=MAX_SYSTEM_SPEED;
+      speed=U61_MAP_MAX_SYSTEM_SPEED;
     }
   if (speed<0)
     {
@@ -1158,9 +1151,9 @@ int U61_Map::get_accel()
  */
 void U61_Map::check_accel()
 {
-  if (accel>MAX_SYSTEM_ACCEL)
+  if (accel>U61_MAP_MAX_SYSTEM_ACCEL)
     {
-      accel=MAX_SYSTEM_ACCEL;
+      accel=U61_MAP_MAX_SYSTEM_ACCEL;
     }
   if (accel<0)
     {
@@ -1183,7 +1176,7 @@ U61_Block U61_Map::get_next_block()
  */
 void U61_Map::blow_up_square(int x,int y)
 {
-  if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
+  if (x>=0 && y>=0 && x<U61_MAP_WIDTH && y<U61_MAP_HEIGHT)
     {
       squares[x][y].begin_explosion();
     }
@@ -1197,7 +1190,7 @@ bool U61_Map::is_square_exploding(int x,int y)
 {
   bool result=false;
 
-  if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
+  if (x>=0 && y>=0 && x<U61_MAP_WIDTH && y<U61_MAP_HEIGHT)
     {
       result= squares[x][y].is_exploding();
     }
@@ -1214,8 +1207,8 @@ bool U61_Map::exists_explosion()
   bool result=false;
   int x,y;
 
-  for (y=0;y<HEIGHT;++y)
-    for (x=0;x<WIDTH;++x)
+  for (y=0;y<U61_MAP_HEIGHT;++y)
+    for (x=0;x<U61_MAP_WIDTH;++x)
       {
 	if (squares[x][y].is_exploding())
 	  {
@@ -1435,7 +1428,7 @@ void U61_Map::name_add_letter(char c)
   int len;
 
   len=strlen(name);
-  if (len<NAME_SIZE)
+  if (len<U61_MAP_NAME_SIZE)
     {
       name[len]=c;
       name[len+1]=0;
@@ -1492,7 +1485,7 @@ bool U61_Map::is_block_ok(U61_Block *test)
        * the square must be in the map, or over the map,
        * if the block is brand new and didn't show himself yet
        */
-      if (x>=0 && x<WIDTH && y<HEIGHT)
+      if (x>=0 && x<U61_MAP_WIDTH && y<U61_MAP_HEIGHT)
         {
 	  /*
 	   * if y>=0, there could potentially be a stable square
@@ -1523,14 +1516,18 @@ bool U61_Map::is_block_ok(U61_Block *test)
 void U61_Map::new_block(int shape)
 {
   block=next_block;
-  block.set_x(WIDTH/2);
+  block.set_x(U61_MAP_WIDTH/2);
   block_requested=false;
 
   next_block.reset();
   U61_Script::do_shape(this,&next_block,shape);
   next_block.center();
+  /*
+   * I used to corner the block before drawing it. Now they are drawn centered
+   * right away, so this line became useless.
+   */
+  //next_block.corner();
 
-  next_block.corner();
   block.center();
 
   U61_LOG_DEBUG("new block given");
@@ -1565,7 +1562,7 @@ void U61_Map::stabilize_block()
     {
       x=block.get_x()+block.get_item_x(i);
       y=block.get_y()+block.get_item_y(i);
-      if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
+      if (x>=0 && y>=0 && x<U61_MAP_WIDTH && y<U61_MAP_HEIGHT)
         {
 	  squares[x][y]=block.get_item(i)->square;
         }
@@ -1576,7 +1573,7 @@ void U61_Map::stabilize_block()
     }
   if (outside)
     {
-      evt.code=U61_Event::LOOSE;
+      evt.code=U61_EVENT_LOOSE;
       put_auto_event(evt);
     }
   else
@@ -1597,6 +1594,7 @@ void U61_Map::loose()
   if (!silent)
     {
       U61_Sound::play_player_loose();
+      U61_Music::change();
     }
 
   U61_LOG_DEBUG("The game is lost");
@@ -1663,8 +1661,8 @@ void U61_Map::update_explosions()
   bool curse_exploded=false;
   U61_Event event;
 
-  for (y=0;y<HEIGHT;++y)
-    for (x=0;x<WIDTH;++x)
+  for (y=0;y<U61_MAP_HEIGHT;++y)
+    for (x=0;x<U61_MAP_WIDTH;++x)
       { 
 	squares[x][y].update_explosion();
 	if (squares[x][y].is_explosion_ended())
@@ -1696,7 +1694,7 @@ void U61_Map::update_explosions()
        *     someone sent it to you and one you got by yourself matching
        *     a pattern, and I just like this idea
        */
-      event.code=U61_Event::DO_CURSE;
+      event.code=U61_EVENT_DO_CURSE;
       event.par=curse_id;
       put_auto_event(event);
 
@@ -1726,8 +1724,8 @@ void U61_Map::new_curse(int id)
   U61_LOG_DEBUG("New curse");
 
   nb_squares=0;
-  for (y=0;y<HEIGHT;++y)
-    for (x=0;x<WIDTH;++x)
+  for (y=0;y<U61_MAP_HEIGHT;++y)
+    for (x=0;x<U61_MAP_WIDTH;++x)
       {
         if (squares[x][y].is_enabled() && 
 	    !squares[x][y].is_exploding())
@@ -1748,8 +1746,8 @@ void U61_Map::new_curse(int id)
        */
       chosen_pos=map_time%nb_squares;
       pos=0;
-      for (y=0;y<HEIGHT;++y)
-        for (x=0;x<WIDTH;++x)
+      for (y=0;y<U61_MAP_HEIGHT;++y)
+        for (x=0;x<U61_MAP_WIDTH;++x)
 	  {
 	    if (squares[x][y].is_enabled() &&
 		!squares[x][y].is_exploding())
@@ -1781,8 +1779,8 @@ void U61_Map::request_curse(U61_Event event)
    * we decide to issue a real curse. It's important to call
    * put_auto_event because of time stamp issues.
    */
-  event.code=U61_Event::DO_CURSE;
-  event.par+=MAX_CURSE_ID;
+  event.code=U61_EVENT_DO_CURSE;
+  event.par+=U61_MAP_MAX_CURSE_ID;
 
   put_auto_event(event);
 }
@@ -1793,7 +1791,7 @@ void U61_Map::request_curse(U61_Event event)
  */
 void U61_Map::do_curse(U61_Event evt)
 {
-  if (evt.par<(unsigned int) MAX_CURSE_ID)
+  if (evt.par<(unsigned int) U61_MAP_MAX_CURSE_ID)
     {
       U61_LOG_DEBUG("Do own curse "<<evt);
       U61_Script::do_curse(this,&block,evt.par,false);
@@ -1801,7 +1799,7 @@ void U61_Map::do_curse(U61_Event evt)
   else
     {
       curse_received++;
-      evt.par-=MAX_CURSE_ID;
+      evt.par-=U61_MAP_MAX_CURSE_ID;
       U61_LOG_DEBUG("Do remote curse "<<evt);
       U61_Script::do_curse(this,&block,evt.par,true);
       if (!silent)
@@ -1843,7 +1841,7 @@ void U61_Map::check_curse()
 void U61_Map::next_victim(U61_Event *event)
 {
   target_id=U61_Global::layout.get_next_player_id(target_id,player_id);
-  event->code=U61_Event::SET_VICTIM;
+  event->code=U61_EVENT_SET_VICTIM;
   event->par=target_id;
   U61_LOG_DEBUG("Next victim "<<target_id);
 }
@@ -1855,7 +1853,7 @@ void U61_Map::next_victim(U61_Event *event)
 void U61_Map::prev_victim(U61_Event *event)
 {
   target_id=U61_Global::layout.get_prev_player_id(target_id,player_id);
-  event->code=U61_Event::SET_VICTIM;
+  event->code=U61_EVENT_SET_VICTIM;
   event->par=target_id;
   U61_LOG_DEBUG("Prev victim "<<target_id);
 }
@@ -1892,7 +1890,7 @@ void U61_Map::check_target()
   test_id=U61_Global::layout.check_player_id(target_id,player_id);
   if (test_id!=target_id)
     {
-      event.code=U61_Event::SET_VICTIM;
+      event.code=U61_EVENT_SET_VICTIM;
       event.par=test_id;
       put_auto_event(event);
       U61_LOG_DEBUG("Correcting victim "<<test_id);
@@ -1923,7 +1921,7 @@ void U61_Map::check_block()
    * First step, we check that the block is not on the right or on
    * the left. Basically we want to put it "back in the middle"
    */
-  min_x=WIDTH-1;
+  min_x=U61_MAP_WIDTH-1;
   max_x=0;
   for (i=0;i<n;++i)
     {
@@ -1947,9 +1945,9 @@ void U61_Map::check_block()
   /*
    * we move the block to the left if needed
    */
-  if (max_x>WIDTH-1)
+  if (max_x>U61_MAP_WIDTH-1)
     {
-      block.set_x(block.get_x()-max_x+WIDTH-1);
+      block.set_x(block.get_x()-max_x+U61_MAP_WIDTH-1);
     }
 
   /*
