@@ -53,6 +53,27 @@
 #include "event.h"
 #include "data.h"
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_MAP_WIDTH 10
+#define U61_MAP_HEIGHT 25
+#define U61_MAP_NAME_SIZE 8
+#define U61_MAP_NB_GLOBAL 1000
+#define U61_MAP_MAX_CURSE_ID 1000
+#define U61_MAP_SPEED_SCALE 1000
+#define U61_MAP_ACCEL_SCALE 1000000
+#define U61_MAP_TIME_CALLBACK_DELAY 10
+#define U61_MAP_CHECK_TARGET_DELAY 100
+#define U61_MAP_CHECK_CURSE_DELAY 100
+#define U61_MAP_ANTICIPATE_MAX 1000
+#define U61_MAP_MAX_USER_SPEED 20
+#define U61_MAP_MAX_USER_ACCEL 10
+#define U61_MAP_MAX_SYSTEM_SPEED 50
+#define U61_MAP_MAX_SYSTEM_ACCEL 15
+#define U61_MAP_MAX_SCORE 100000000
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -117,7 +138,7 @@ public:
     int get_target_id();
 
     void draw(int x,int y, 
-              int size=U61_Data::SIZE_BIG,
+              int size=U61_DATA_SIZE_BIG,
               bool anti=false);
 
     void mute();
@@ -146,36 +167,17 @@ public:
 
     U61_Block get_next_block();
 
-    static const int WIDTH=10;
-    static const int HEIGHT=25;
-    static const int NAME_SIZE=8;
-    static const int NB_GLOBAL=1000;
-    static const int MAX_CURSE_ID=1000;
-    static const int SPEED_SCALE=1000;
-    static const int ACCEL_SCALE=1000000;
-    static const int TIME_CALLBACK_DELAY=10;
-    static const int CHECK_TARGET_DELAY=100;
-    static const int CHECK_CURSE_DELAY=100;
-    static const int ANTICIPATE_MAX=1000;
-    static const int MAX_USER_SPEED=20;
-    static const int MAX_USER_ACCEL=10;
-    static const int MAX_SYSTEM_SPEED=50;
-    static const int MAX_SYSTEM_ACCEL=15;
-    static const int MAX_SCORE=100000000;
 protected:
-    static const int speeds[MAX_SYSTEM_SPEED+1];
-    static const int accels[MAX_SYSTEM_ACCEL+1];
-
-    U61_Square squares[WIDTH][HEIGHT];
+    U61_Square squares[U61_MAP_WIDTH][U61_MAP_HEIGHT];
     U61_Block block;
     U61_Block next_block;
     U61_Block block_anticipation;
-    list<U61_Event> auto_events;
-    list<U61_Event> request_events;
-    int global_val[NB_GLOBAL];
-    int curse_begin[MAX_CURSE_ID];
-    int curse_end[MAX_CURSE_ID];
-    char name[NAME_SIZE+1];
+    std::list<U61_Event> auto_events;
+    std::list<U61_Event> request_events;
+    int global_val[U61_MAP_NB_GLOBAL];
+    int curse_begin[U61_MAP_MAX_CURSE_ID];
+    int curse_end[U61_MAP_MAX_CURSE_ID];
+    char name[U61_MAP_NAME_SIZE+1];
 
     int player_id;
     int target_id;
@@ -214,7 +216,7 @@ protected:
     void put_auto_event(U61_Event event);
     void put_request_event(U61_Event event);
 
-    void draw_anticipation(int x,int y, int size=U61_Data::SIZE_BIG);
+    void draw_anticipation(int x,int y, int size=U61_DATA_SIZE_BIG);
 
     void block_rotate_left();
     void block_rotate_right();
