@@ -39,6 +39,10 @@
  includes
  ---------------------------------------------------------------------------*/
 
+#ifdef U61_MSVC
+#include <minmax.h>
+#endif
+
 #include "menu.h"
 #include "time.h"
 #include "sound.h"
@@ -54,7 +58,7 @@
 /*
  * messages displayed at the bottom of the screen in the menus
  */
-char *U61_Menu::bottom_message[BOTTOM_MESSAGE_NB]=
+char *U61_Menu::bottom_message[U61_MENU_BOTTOM_MESSAGE_NB]=
 {
   "U61, another block-based game by U-Foot",
   "Copyright (C) 2000 Christian Mauduit",
@@ -474,7 +478,7 @@ void U61_Menu::draw_bottom_message()
   int x,y=0,dx;
 
   dx=(U61_Time::for_effect()-bottom_message_start_time)
-    /BOTTOM_MESSAGE_DELAY;
+    /U61_MENU_BOTTOM_MESSAGE_DELAY;
   if (dx>=U61_Global::data.screen_w+bottom_message_width)
     {
       init_bottom_message(); 
@@ -495,7 +499,7 @@ void U61_Menu::draw_bottom_message()
 void U61_Menu::init_bottom_message()
 {
   current_bottom_message++;
-  if (current_bottom_message>=BOTTOM_MESSAGE_NB)
+  if (current_bottom_message>=U61_MENU_BOTTOM_MESSAGE_NB)
     {
       current_bottom_message=0;
     }
