@@ -55,6 +55,24 @@
  */    
 CL_SoundBuffer_Session *U61_Music::session=NULL;
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Counter used to know when the current music must be changed
+ */    
+int U61_Music::change_counter=0;
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Index of the last chosen music
+ */    
+int U61_Music::last_chosen=-1;
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Number of times to call change() before the music actually changes
+ */    
+int U61_Music::change_limit=1;
+
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
@@ -65,30 +83,42 @@ CL_SoundBuffer_Session *U61_Music::session=NULL;
  */
 void U61_Music::start()
 {
-  /*
-  CL_SoundBuffer *sample;
   int volume;
-  int chosen=0;
 
-  chosen=U61_Utils::random(U61_Global::data.nb_music);
+  if (session==NULL)
+    {
+      change(true);
+    }
 
-  volume=U61_Global::config.sound_volume;
-
-  sample=U61_Global::data.music[chosen];
+  if (session!=NULL)
+    {
+      volume=U61_Global::config.sound_volume;
+   
+      if (volume>0)
+	{
+	  session->set_volume(2.0*((float) volume)
+			      /((float) U61_MUSIC_VOLUME_MAX));
+	  session->set_position(0);
+	  if (!session->is_playing())
+	    {
+	      session->play();
+	    }
+	}
+    }
+}
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Stops playing the music (called when one exists a game)
+ */
+void U61_Music::stop()
+{
   if (session!=NULL)
     {
       session->stop();
       delete session;
+      session=NULL;
     }
-
-  session=new CL_SoundBuffer_Session(sample->prepare());
-  if (session!=NULL)
-    {
-      session->set_volume(2.0*((float) volume)/((float) VOLUME_MAX));
-      session->play();
-    }
-  */
 }
 
 /*--------------------------------------------------------------------------*/
@@ -97,22 +127,29 @@ void U61_Music::start()
  */
 void U61_Music::update()
 {
-  /*
   int volume;
 
-  volume=U61_Global::config.sound_volume;
+  volume=U61_Global::config.music_volume;
   if (session!=NULL)
     {
-      if (session->is_playing())
+      if (volume>0)
 	{
-	  session->set_volume(2.0*((float) volume)/((float) VOLUME_MAX));
+	  if (!session->is_playing())
+	    {
+	      start();
+	    }
+
+	  if (session!=NULL)
+	    {	  
+	      session->set_volume(2.0*((float) volume)
+				  /((float) U61_MUSIC_VOLUME_MAX));
+	    }
 	}
       else
 	{
-	  start();
+	  session->stop();
 	}
     }
-  */
 }
 
 /*--------------------------------------------------------------------------*/
@@ -132,3 +169,57 @@ void U61_Music::resume()
 {
 
 }
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Sets the "change limit". In fact, change only calls changes the current
+ * music if it has been called a minimum number of times. This avoids the
+ * music to change all the time in a local multiplayer game.
+ */
+void U61_Music::set_change_limit(int limit)
+{
+  change_limit=limit;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Changes the current music.
+ */
+void U61_Music::change(bool force)
+{
+  int chosen=0;
+
+  if (force)
+    {
+      change_counter=change_limit;
+    }
+
+  change_counter++;
+  if (change_counter>=change_limit)
+    {
+      change_counter=0;
+      if (U61_Global::data.nb_music>0)
+	{
+	  chosen=U61_Utils::random(U61_Global::data.nb_music);
+	  /*
+	   * Now this is a little trick so than when there are at least
+	   * 2 different musics, we are sure the music changes for good
+	   */
+	  if (U61_Global::data.nb_music>1)
+	    {
+	      while (chosen==last_chosen)
+		{
+		  chosen=U61_Utils::random(U61_Global::data.nb_music);
+		}
+	    }
+
+	  last_chosen=chosen;
+
+	  stop();
+
+	  session=new CL_SoundBuffer_Session
+	    (U61_Global::data.music[chosen]->prepare());
+	}
+    }
+}
+
