@@ -45,6 +45,13 @@
 
 #include <ClanLib/core.h>
 
+
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_MUSIC_VOLUME_MAX 10
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -53,13 +60,19 @@ class U61_Music
 {
  public:
   static void start();
+  static void stop();
   static void update();
   static void pause();
   static void resume();
 
-  static const int VOLUME_MAX=10;
+  static void set_change_limit(int limit=1);
+  static void change(bool force=false);
+
  protected:
   static CL_SoundBuffer_Session *session;
+  static int change_counter;
+  static int last_chosen;
+  static int change_limit;
 };
 
 #endif
