@@ -50,6 +50,18 @@
 #include "event.h"
 #include "packet.h"
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_PACKET_MAX_DATA 256
+
+#define U61_PACKET_SYSTEM 0
+#define U61_PACKET_DUMMY 1
+#define U61_PACKET_INIT 2
+#define U61_PACKET_EVENT 3
+#define U61_PACKET_CURSE_REQUEST 4
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -60,17 +72,9 @@ class U61_Packet
   U61_Packet();
   ~U61_Packet();
 
-  static const int MAX_DATA=256;
-
-  static const int SYSTEM=0;
-  static const int DUMMY=1;
-  static const int INIT=2;
-  static const int EVENT=3;
-  static const int CURSE_REQUEST=4;
-
   short type;
   short size;
-  char data[MAX_DATA];   
+  char data[U61_PACKET_MAX_DATA];   
 
   bool is_event();
   void set_event(U61_Event e);
