@@ -45,6 +45,8 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <syslog.h>
+#include <ClanLib/mikmod.h>
+#include <ClanLib/lua.h>
 
 #include "platform.h"
 #include "const.h"
@@ -78,17 +80,35 @@ static FILE *debug_file=NULL;
 static DIR *scan_dir=NULL;
 static char *scan_ext=NULL;
 
+/*--------------------------------------------------------------------------*/
+/*
+ * This array contains some typical paths where the game could be installed.
+ * In case the path specified in the config file fails, we try all these
+ * paths. This way the game with still work even if the player has a static
+ * binary exe that is installed in /usr/bin and a custome built datafile
+ * which is in /usr/local/share...
+ */
+#define NB_STANDARD_PATHS 5
+static char *standard_paths[NB_STANDARD_PATHS]=
+{
+  U61_INSTALL_DATA_PATH,
+  "/usr/local/share/u61/",
+  "/usr/share/u61/",
+  "/usr/local/share/games/u61/",
+  "/usr/share/games/u61/"
+};
+
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
 
 /*--------------------------------------------------------------------------*/
 /*
- * returns the home path of the user /home/ufoot for instance
+ * returns the user path (/home/ufoot/.u61/ for instance)
  */
-char *U61_Platform::get_home_path()
+char *U61_Platform::get_user_path()
 {
-  static char buffer[U61_STRING_SIZE]; 
+  static char buffer[U61_CONST_STRING_SIZE]; 
   int len;
 
   strcpy (buffer,getenv("HOME"));
@@ -105,18 +125,6 @@ char *U61_Platform::get_home_path()
       strcpy(buffer,"./");
     }
 
-  return buffer;
-}
-
-/*--------------------------------------------------------------------------*/
-/*
- * returns the user path (/home/ufoot/.u61/ for instance)
- */
-char *U61_Platform::get_user_path()
-{
-  static char buffer[U61_STRING_SIZE]; 
-
-  strcpy(buffer,get_home_path());
   strcat(buffer,".u61/");
 
   return buffer;
@@ -128,11 +136,38 @@ char *U61_Platform::get_user_path()
  */
 char *U61_Platform::get_data_path()
 {
-  static char buffer[U61_STRING_SIZE]; 
-  int len;
+  static char buffer[U61_CONST_STRING_SIZE]; 
+  DIR *d;
+  int len,i;
 
+  strcpy (buffer,U61_INSTALL_DATA_PATH);
+  d=opendir(buffer);
+  if (d==NULL)
+    {  
+      /*
+       * If we are here it means the path in the config file does not
+       * exist. OK, than we'll try something else!
+       */
+      for (i=0;i<NB_STANDARD_PATHS;++i)
+	{
+	  d=opendir(standard_paths[i]);
+	  if (d!=NULL)
+	    {
+	      /*
+	       * We've found an existing directory named u61, we'd be
+	       * really unlucky if it wasn't the right one...
+	       */
+	      strcpy(buffer,standard_paths[i]);
+	      i=NB_STANDARD_PATHS;
+	      closedir(d);
+	    }
+	}
+    }
+  else
+    {
+      closedir(d);
+    }
 
-  strcpy (buffer,INSTALL_DATA_PATH);
   len=strlen(buffer);
   if (len>0)
     {
@@ -151,7 +186,7 @@ char *U61_Platform::get_data_path()
  */
 char *U61_Platform::get_builtin_theme_path()
 {
-  static char buffer[U61_STRING_SIZE];
+  static char buffer[U61_CONST_STRING_SIZE];
 
   strcpy(buffer,get_data_path());
   strcat(buffer,"theme/");
@@ -165,7 +200,7 @@ char *U61_Platform::get_builtin_theme_path()
  */
 char *U61_Platform::get_builtin_script_path()
 {
-  static char buffer[U61_STRING_SIZE];
+  static char buffer[U61_CONST_STRING_SIZE];
 
   strcpy(buffer,get_data_path());
   strcat(buffer,"script/");
@@ -179,7 +214,7 @@ char *U61_Platform::get_builtin_script_path()
  */
 char *U61_Platform::get_user_theme_path()
 {
-  static char buffer[U61_STRING_SIZE];
+  static char buffer[U61_CONST_STRING_SIZE];
 
   strcpy(buffer,get_user_path());
   strcat(buffer,"theme/");
@@ -193,7 +228,7 @@ char *U61_Platform::get_user_theme_path()
  */
 char *U61_Platform::get_user_script_path()
 {
-  static char buffer[U61_STRING_SIZE];
+  static char buffer[U61_CONST_STRING_SIZE];
 
   strcpy(buffer,get_user_path());
   strcat(buffer,"script/");
@@ -207,7 +242,7 @@ char *U61_Platform::get_user_script_path()
  */
 char *U61_Platform::get_config_file()
 {
-  static char buffer[U61_STRING_SIZE]; 
+  static char buffer[U61_CONST_STRING_SIZE]; 
 
   strcpy (buffer,get_user_path());
   strcat(buffer,"config.lua");
@@ -221,7 +256,7 @@ char *U61_Platform::get_config_file()
  */
 void U61_Platform::strip_remote_script_path(char *path)
 {
-  char buffer[U61_STRING_SIZE];
+  char buffer[U61_CONST_STRING_SIZE];
   char *pos;
 
   /*
@@ -250,7 +285,7 @@ void U61_Platform::strip_remote_script_path(char *path)
  */
 void U61_Platform::unstrip_remote_script_path(char *path)
 {
-  char buffer[U61_STRING_SIZE];
+  char buffer[U61_CONST_STRING_SIZE];
 
   // Gets the user script path "/home/ufoot/.u61/script/"
   strncpy(buffer,get_user_script_path(),sizeof(buffer)-1);
@@ -347,6 +382,7 @@ bool U61_Platform::create_user_dir()
   test=opendir(get_user_path());
   if (test!=NULL)
     {
+      closedir(test);
       ok=true;
     }    
   else
@@ -370,12 +406,14 @@ bool U61_Platform::create_user_dir()
  */
 void U61_Platform::exec(char *file)
 {
-  char buffer[U61_STRING_SIZE];
+  char buffer[U61_CONST_STRING_SIZE];
   int len;
 
   U61_LOG_MESSAGE("Restarting...");
   U61_Debug::deinit();
 
+  CL_Lua::close();
+  CL_SetupMikMod::deinit();
   CL_SetupCore::deinit_network();    
   CL_SetupCore::deinit_sound();
   CL_SetupCore::deinit_display();
@@ -395,7 +433,7 @@ void U61_Platform::exec(char *file)
    * this should replace u61 by /usr/local/bin/u61
    * for instance.
    */
-  strcpy(buffer,INSTALL_BIN_PATH);
+  strcpy(buffer,U61_INSTALL_BIN_PATH);
   len=strlen(buffer);
   if (len>0)
     {
@@ -425,7 +463,7 @@ void U61_Platform::exec(char *file)
  */
 void U61_Platform::open_score_file()
 {
-  char buffer[U61_STRING_SIZE];
+  char buffer[U61_CONST_STRING_SIZE];
 
   if (score_file==NULL)
     {
@@ -458,7 +496,7 @@ void U61_Platform::dump_score(char *text)
 {
   time_t curtime;
   struct tm *loctime;
-  char buffer_date[U61_STRING_SIZE];
+  char buffer_date[U61_CONST_STRING_SIZE];
 
   if (score_file!=NULL)
     {     
@@ -494,7 +532,7 @@ void U61_Platform::open_log_files()
   openlog("u61",LOG_PID,LOG_USER);
 
 #ifdef DEBUG
-  char buffer[U61_STRING_SIZE];
+  char buffer[U61_CONST_STRING_SIZE];
 
   if (debug_file==NULL)
     {
