@@ -196,6 +196,15 @@ char *U61_Player::get_curse_name()
   return last.get_curse_name();
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the index of the background to be displayed
+ */
+int U61_Player::get_background()
+{
+  return last.get_background();
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * sets the player as a local player
@@ -325,7 +334,7 @@ void U61_Player::pump_events()
       copy->put(evt);
       switch (evt.code)
 	{
-	case U61_Event::KILL:
+	case U61_EVENT_KILL:
 	  kill_needed=true;
 	  break;
 	}
@@ -358,11 +367,11 @@ void U61_Player::handle_event(U61_Event *evt)
 {
   if (sure.is_active())
     {
-      if (evt->code==U61_Event::LOOSE)
+      if (evt->code==U61_EVENT_LOOSE)
 	{
 	  register_score();
 	}
-      if (evt->code==U61_Event::START_STOP)
+      if (evt->code==U61_EVENT_START_STOP)
 	{
 	  stop();
 	}
@@ -373,7 +382,7 @@ void U61_Player::handle_event(U61_Event *evt)
     }
   else
     {
-      if (evt->code==U61_Event::START_STOP)
+      if (evt->code==U61_EVENT_START_STOP)
 	{
 	  start(evt->time);
 	} 
