@@ -89,6 +89,7 @@ class U61_Player
   int get_nb_curse();
   int get_nb_antidote();
   char *get_curse_name();
+  int get_background();
 
   void init_local(U61_Input *input,
                   U61_Dispatcher *d,
@@ -105,7 +106,7 @@ class U61_Player
 
   void pump_events();
 
-  void draw(int x,int y,int size=U61_Data::SIZE_BIG);
+  void draw(int x,int y,int size=U61_DATA_SIZE_BIG);
 
   void kill();
  protected:
@@ -131,3 +132,5 @@ class U61_Player
 };
 
 #endif
+
+
