@@ -54,9 +54,75 @@
 #include "debug.h"
 
 /*---------------------------------------------------------------------------
- variants
+ constants
  ---------------------------------------------------------------------------*/
 
+#define U61_SCRIPT_LUA_NEW_SHAPE "user_new_shape"
+#define U61_SCRIPT_LUA_DO_SHAPE "user_do_shape"
+#define U61_SCRIPT_LUA_ROTATE_LEFT "user_rotate_left"
+#define U61_SCRIPT_LUA_ROTATE_RIGHT "user_rotate_right"
+#define U61_SCRIPT_LUA_MOVE_LEFT "user_move_left"
+#define U61_SCRIPT_LUA_MOVE_RIGHT "user_move_right"
+#define U61_SCRIPT_LUA_MOVE_DOWN "user_move_down"
+#define U61_SCRIPT_LUA_LAND "user_land"
+#define U61_SCRIPT_LUA_MATCH_PATTERN "user_match_pattern"
+#define U61_SCRIPT_LUA_TIME_CALLBACK "user_time_callback"
+#define U61_SCRIPT_LUA_SQUARE_BLOWN_UP "user_square_blown_up"
+#define U61_SCRIPT_LUA_NEW_CURSE "user_new_curse"
+#define U61_SCRIPT_LUA_DO_CURSE "user_do_curse"
+#define U61_SCRIPT_LUA_USE_ANTIDOTE "user_use_antidote"
+#define U61_SCRIPT_LUA_GET_CURSE_NAME "user_get_curse_name"
+
+#define U61_SCRIPT_C_RESET_BLOCK "u61_reset_block"
+#define U61_SCRIPT_C_CENTER_BLOCK "u61_center_block"
+#define U61_SCRIPT_C_GET_BLOCK_X "u61_get_block_x"
+#define U61_SCRIPT_C_GET_BLOCK_Y "u61_get_block_y"
+#define U61_SCRIPT_C_SET_BLOCK_X "u61_set_block_x"
+#define U61_SCRIPT_C_SET_BLOCK_Y "u61_set_block_y"
+#define U61_SCRIPT_C_ADD_ITEM "u61_add_item"
+#define U61_SCRIPT_C_GET_NB_ITEMS "u61_get_nb_items"
+#define U61_SCRIPT_C_GET_ITEM_X "u61_get_item_x"
+#define U61_SCRIPT_C_GET_ITEM_Y "u61_get_item_y"
+#define U61_SCRIPT_C_GET_ITEM_COLOR "u61_get_item_color"
+#define U61_SCRIPT_C_SET_ITEM_X "u61_set_item_x"
+#define U61_SCRIPT_C_SET_ITEM_Y "u61_set_item_y"
+#define U61_SCRIPT_C_SET_ITEM_COLOR "u61_set_item_color"
+#define U61_SCRIPT_C_GET_WIDTH "u61_get_width"
+#define U61_SCRIPT_C_GET_HEIGHT "u61_get_height"
+#define U61_SCRIPT_C_GET_SQUARE_COLOR "u61_get_square_color"
+#define U61_SCRIPT_C_SET_SQUARE_COLOR "u61_set_square_color"
+#define U61_SCRIPT_C_GET_TIME "u61_get_time"
+#define U61_SCRIPT_C_GET_SCORE "u61_get_score"
+#define U61_SCRIPT_C_SET_SCORE "u61_set_score"
+#define U61_SCRIPT_C_ADD_SCORE "u61_add_score"
+#define U61_SCRIPT_C_GET_GLOBAL "u61_get_global"
+#define U61_SCRIPT_C_SET_GLOBAL "u61_set_global"
+#define U61_SCRIPT_C_GET_ANTICIPATION_STATE "u61_get_anticipation_state"
+#define U61_SCRIPT_C_SET_ANTICIPATION_STATE "u61_set_anticipation_state"
+#define U61_SCRIPT_C_GET_PREVIEW_STATE "u61_get_preview_state"
+#define U61_SCRIPT_C_SET_PREVIEW_STATE "u61_set_preview_state"
+#define U61_SCRIPT_C_BLOW_UP_SQUARE "u61_blow_up_square"
+#define U61_SCRIPT_C_IS_SQUARE_EXPLODING "u61_is_square_exploding"
+#define U61_SCRIPT_C_GET_CURSE_X "u61_get_curse_x"
+#define U61_SCRIPT_C_GET_CURSE_Y "u61_get_curse_y"
+#define U61_SCRIPT_C_GET_CURSE_STATE "u61_get_curse_state"
+#define U61_SCRIPT_C_SET_CURSE_X "u61_set_curse_x"
+#define U61_SCRIPT_C_SET_CURSE_Y "u61_set_curse_y"
+#define U61_SCRIPT_C_SET_CURSE_STATE "u61_set_curse_state"
+#define U61_SCRIPT_C_IS_CURSE_AVAILABLE "u61_is_curse_available"
+#define U61_SCRIPT_C_SEND_CURSE "u61_send_curse"
+#define U61_SCRIPT_C_GET_CURSE_AGE "u61_get_curse_age"
+#define U61_SCRIPT_C_REGISTER_CURSE "u61_register_curse"
+#define U61_SCRIPT_C_CANCEL_CURSE "u61_cancel_curse"
+#define U61_SCRIPT_C_GET_OLDEST_CURSE "u61_get_oldest_curse"
+#define U61_SCRIPT_C_GET_NB_CURSES "u61_get_nb_curses"
+#define U61_SCRIPT_C_GET_NB_ANTIDOTES "u61_get_nb_antidotes"
+#define U61_SCRIPT_C_ADD_ANTIDOTE "u61_add_antidote"
+#define U61_SCRIPT_C_DELETE_ANTIDOTE "u61_delete_antidote"
+#define U61_SCRIPT_C_IS_BLOCK_OK "u61_is_block_ok"
+
+#define U61_SCRIPT_RANDOM_MAX 0x7FFFFFFF
+
 /*--------------------------------------------------------------------------*/
 /*
  * the following pointers allow tradionnal C functions, called by Lua,
@@ -159,7 +225,7 @@ char *U61_Script::get_global_str(char *name,char *def)
 
 /*--------------------------------------------------------------------------*/
 /*
- * retrieves a global lua value as a string
+ * retrieves a global lua value as an integer
  */
 int U61_Script::get_global_int(char *name,int def)
 {
@@ -175,6 +241,24 @@ int U61_Script::get_global_int(char *name,int def)
   return (int) result;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * retrieves a global lua value as a boolean
+ */
+bool U61_Script::get_global_bool(char *name,bool def)
+{
+  CL_LuaObject obj;
+  bool result=def;
+
+  obj=CL_Lua::getglobal(name);
+  if (obj.isNumber())
+    {
+      result=(((float) obj)!=0);
+    }    
+
+  return result;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * registers all C functions that can be used from Lua
@@ -242,9 +326,9 @@ int U61_Script::new_shape(U61_Map *m,U61_Block *b)
    * Now I use lua API directly and not ClanLib's wrapper since I could
    * not manage to get it work...
    */
-  lua_pushnumber(U61_Utils::random(RANDOM_MAX));
+  lua_pushnumber(U61_Utils::random(U61_SCRIPT_RANDOM_MAX));
 
-  func=lua_getglobal(LUA_NEW_SHAPE);
+  func=lua_getglobal(U61_SCRIPT_LUA_NEW_SHAPE);
   if (lua_isfunction(func))
     {
       lua_callfunction(func);
@@ -268,8 +352,8 @@ int U61_Script::new_shape(U61_Map *m,U61_Block *b)
 void U61_Script::do_shape(U61_Map *m,U61_Block *b, int type)
 {
   CL_LuaObject func;
-  char command[U61_STRING_SIZE];
-  char arguments[U61_STRING_SIZE];
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
 
   secure_pointers();
   current_map=m;
@@ -278,11 +362,11 @@ void U61_Script::do_shape(U61_Map *m,U61_Block *b, int type)
   block_read=true;
   block_write=true;
 
-  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //func=CL_Lua::getglobal(U61_SCRIPT_LUA_NEW_BLOCK);
   //lua_callfunction(func);
 
   sprintf(arguments,"(%d)",type);
-  strcpy(command,LUA_DO_SHAPE);
+  strcpy(command,U61_SCRIPT_LUA_DO_SHAPE);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -298,8 +382,8 @@ void U61_Script::do_shape(U61_Map *m,U61_Block *b, int type)
 void U61_Script::rotate_right(U61_Map *m,U61_Block *b)
 {
   CL_LuaObject func;
-  char command[U61_STRING_SIZE];
-  char arguments[U61_STRING_SIZE];
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
 
   secure_pointers();
   current_map=m;
@@ -308,11 +392,11 @@ void U61_Script::rotate_right(U61_Map *m,U61_Block *b)
   block_read=true;
   block_write=true;
 
-  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //func=CL_Lua::getglobal(U61_SCRIPT_LUA_NEW_BLOCK);
   //lua_callfunction(func);
 
   sprintf(arguments,"()");
-  strcpy(command,LUA_ROTATE_RIGHT);
+  strcpy(command,U61_SCRIPT_LUA_ROTATE_RIGHT);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -328,8 +412,8 @@ void U61_Script::rotate_right(U61_Map *m,U61_Block *b)
 void U61_Script::rotate_left(U61_Map *m,U61_Block *b)
 {
   CL_LuaObject func;
-  char command[U61_STRING_SIZE];
-  char arguments[U61_STRING_SIZE];
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
 
   secure_pointers();
   current_map=m;
@@ -338,11 +422,11 @@ void U61_Script::rotate_left(U61_Map *m,U61_Block *b)
   block_read=true;
   block_write=true;
 
-  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //func=CL_Lua::getglobal(U61_SCRIPT_LUA_NEW_BLOCK);
   //lua_callfunction(func);
 
   sprintf(arguments,"()");
-  strcpy(command,LUA_ROTATE_LEFT);
+  strcpy(command,U61_SCRIPT_LUA_ROTATE_LEFT);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -358,8 +442,8 @@ void U61_Script::rotate_left(U61_Map *m,U61_Block *b)
 void U61_Script::move_right(U61_Map *m,U61_Block *b)
 {
   CL_LuaObject func;
-  char command[U61_STRING_SIZE];
-  char arguments[U61_STRING_SIZE];
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
 
   secure_pointers();
   current_map=m;
@@ -368,11 +452,11 @@ void U61_Script::move_right(U61_Map *m,U61_Block *b)
   block_read=true;
   block_write=true;
 
-  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //func=CL_Lua::getglobal(U61_SCRIPT_LUA_NEW_BLOCK);
   //lua_callfunction(func);
 
   sprintf(arguments,"()");
-  strcpy(command,LUA_MOVE_RIGHT);
+  strcpy(command,U61_SCRIPT_LUA_MOVE_RIGHT);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -388,8 +472,8 @@ void U61_Script::move_right(U61_Map *m,U61_Block *b)
 void U61_Script::move_left(U61_Map *m,U61_Block *b)
 {
   CL_LuaObject func;
-  char command[U61_STRING_SIZE];
-  char arguments[U61_STRING_SIZE];
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
 
   secure_pointers();
   current_map=m;
@@ -398,11 +482,11 @@ void U61_Script::move_left(U61_Map *m,U61_Block *b)
   block_read=true;
   block_write=true;
 
-  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //func=CL_Lua::getglobal(U61_SCRIPT_LUA_NEW_BLOCK);
   //lua_callfunction(func);
 
   sprintf(arguments,"()");
-  strcpy(command,LUA_MOVE_LEFT);
+  strcpy(command,U61_SCRIPT_LUA_MOVE_LEFT);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -418,8 +502,8 @@ void U61_Script::move_left(U61_Map *m,U61_Block *b)
 void U61_Script::move_down(U61_Map *m,U61_Block *b)
 {
   CL_LuaObject func;
-  char command[U61_STRING_SIZE];
-  char arguments[U61_STRING_SIZE];
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
 
   secure_pointers();
   current_map=m;
@@ -428,11 +512,11 @@ void U61_Script::move_down(U61_Map *m,U61_Block *b)
   block_read=true;
   block_write=true;
 
-  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //func=CL_Lua::getglobal(U61_SCRIPT_LUA_NEW_BLOCK);
   //lua_callfunction(func);
 
   sprintf(arguments,"()");
-  strcpy(command,LUA_MOVE_DOWN);
+  strcpy(command,U61_SCRIPT_LUA_MOVE_DOWN);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -448,8 +532,8 @@ void U61_Script::move_down(U61_Map *m,U61_Block *b)
 void U61_Script::land(U61_Map *m,U61_Block *b)
 {
   CL_LuaObject func;
-  char command[U61_STRING_SIZE];
-  char arguments[U61_STRING_SIZE];
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
 
   secure_pointers();
   current_block=b;
@@ -458,11 +542,11 @@ void U61_Script::land(U61_Map *m,U61_Block *b)
   current_map=m;
   map_read=true;
 
-  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //func=CL_Lua::getglobal(U61_SCRIPT_LUA_NEW_BLOCK);
   //lua_callfunction(func);
 
   sprintf(arguments,"()");
-  strcpy(command,LUA_LAND);
+  strcpy(command,U61_SCRIPT_LUA_LAND);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -477,7 +561,7 @@ void U61_Script::land(U61_Map *m,U61_Block *b)
  */
 bool U61_Script::match_pattern(U61_Map *m)
 {
-  float result=0.;
+  bool result=false;
   lua_Object func,ret;
 
   secure_pointers();
@@ -492,7 +576,7 @@ bool U61_Script::match_pattern(U61_Map *m)
    */
   lua_pushnumber(current_map->get_match_count());
 
-  func=lua_getglobal(LUA_MATCH_PATTERN);
+  func=lua_getglobal(U61_SCRIPT_LUA_MATCH_PATTERN);
   if (lua_isfunction(func))
     {
       lua_callfunction(func);
@@ -501,11 +585,11 @@ bool U61_Script::match_pattern(U61_Map *m)
   ret=lua_getresult(1);
   if (lua_isnumber(ret))
     {
-      result=lua_getnumber(ret);
+      result=(((float) lua_getnumber(ret))!=0.);
     }
   lua_endblock();
 
-  return ((int) result);
+  return result;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -519,8 +603,8 @@ bool U61_Script::match_pattern(U61_Map *m)
 void U61_Script::time_callback(U61_Map *m,U61_Block *b)
 {
   CL_LuaObject func;
-  char command[U61_STRING_SIZE];
-  char arguments[U61_STRING_SIZE];
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
 
   secure_pointers();
   current_map=m;
@@ -530,11 +614,11 @@ void U61_Script::time_callback(U61_Map *m,U61_Block *b)
   block_read=true;
   block_write=true;
 
-  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //func=CL_Lua::getglobal(U61_SCRIPT_LUA_NEW_BLOCK);
   //lua_callfunction(func);
 
   sprintf(arguments,"()");
-  strcpy(command,LUA_TIME_CALLBACK);
+  strcpy(command,U61_SCRIPT_LUA_TIME_CALLBACK);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -553,8 +637,8 @@ void U61_Script::square_blown_up(U61_Map *m,int x,int y)
   CL_LuaObject func;
   CL_LuaObject obj;
   CL_LuaObject arg1;
-  char command[U61_STRING_SIZE];
-  char arguments[U61_STRING_SIZE];
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
 
   secure_pointers();
   current_map=m;
@@ -563,10 +647,10 @@ void U61_Script::square_blown_up(U61_Map *m,int x,int y)
 
   //  lua_pushnumber(x);
   //  lua_pushnumber(y);
-  //  lua_callfunction(lua_getglobal(LUA_MAP_SQUARE_BLOWN_UP));
+  //  lua_callfunction(lua_getglobal(U61_SCRIPT_LUA_MAP_SQUARE_BLOWN_UP));
 
   sprintf(arguments,"(%d,%d)",x,y);
-  strcpy(command,LUA_SQUARE_BLOWN_UP);
+  strcpy(command,U61_SCRIPT_LUA_SQUARE_BLOWN_UP);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -594,9 +678,9 @@ int U61_Script::new_curse(U61_Map *m,U61_Block *b)
    * Now I use lua API directly and not ClanLib's wrapper since I could
    * not manage to get it work...
    */
-  lua_pushnumber(U61_Utils::random(RANDOM_MAX));
+  lua_pushnumber(U61_Utils::random(U61_SCRIPT_RANDOM_MAX));
 
-  func=lua_getglobal(LUA_NEW_CURSE);
+  func=lua_getglobal(U61_SCRIPT_LUA_NEW_CURSE);
   if (lua_isfunction(func))
     {
       lua_callfunction(func);
@@ -622,8 +706,8 @@ void U61_Script::do_curse(U61_Map *m,U61_Block *b,int id,bool sent)
   CL_LuaObject func;
   CL_LuaObject obj;
   CL_LuaObject arg1;
-  char command[U61_STRING_SIZE];
-  char arguments[U61_STRING_SIZE];
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
 
   secure_pointers();
   current_map=m;
@@ -635,10 +719,10 @@ void U61_Script::do_curse(U61_Map *m,U61_Block *b,int id,bool sent)
 
   //  lua_pushnumber(x);
   //  lua_pushnumber(y);
-  //  lua_callfunction(lua_getglobal(LUA_MAP_SQUARE_BLOWN_UP));
+  //  lua_callfunction(lua_getglobal(U61_SCRIPT_LUA_MAP_SQUARE_BLOWN_UP));
 
   sprintf(arguments,"(%d,%d)",id,sent ? 1 : 0);
-  strcpy(command,LUA_DO_CURSE);
+  strcpy(command,U61_SCRIPT_LUA_DO_CURSE);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -653,8 +737,8 @@ void U61_Script::do_curse(U61_Map *m,U61_Block *b,int id,bool sent)
 void U61_Script::use_antidote(U61_Map *m,U61_Block *b)
 {
   CL_LuaObject func;
-  char command[U61_STRING_SIZE];
-  char arguments[U61_STRING_SIZE];
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
 
   secure_pointers();
   current_map=m;
@@ -665,7 +749,7 @@ void U61_Script::use_antidote(U61_Map *m,U61_Block *b)
   block_write=true;
 
   sprintf(arguments,"()");
-  strcpy(command,LUA_USE_ANTIDOTE);
+  strcpy(command,U61_SCRIPT_LUA_USE_ANTIDOTE);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -679,7 +763,7 @@ void U61_Script::use_antidote(U61_Map *m,U61_Block *b)
  */
 char *U61_Script::get_curse_name(U61_Map *m,int id)
 {
-  static char result[U61_STRING_SIZE];
+  static char result[U61_CONST_STRING_SIZE];
   char *str=NULL;
   lua_Object func,ret;
 
@@ -694,7 +778,7 @@ char *U61_Script::get_curse_name(U61_Map *m,int id)
    */
   lua_pushnumber(id);
   
-  func=lua_getglobal(LUA_GET_CURSE_NAME);
+  func=lua_getglobal(U61_SCRIPT_LUA_GET_CURSE_NAME);
   if (lua_isfunction(func))
     {
       lua_callfunction(func);
@@ -974,7 +1058,7 @@ static void get_width()
 {
   if (current_map!=NULL && map_read)
     {
-      return_lua_int (U61_Map::WIDTH);
+      return_lua_int (U61_MAP_WIDTH);
     }
 }
 
@@ -987,7 +1071,7 @@ static void get_height()
 {
   if (current_map!=NULL && map_read)
     {
-      return_lua_int (U61_Map::HEIGHT);
+      return_lua_int (U61_MAP_HEIGHT);
     }
 }
 
@@ -1142,11 +1226,11 @@ static void get_anticipation_state()
  */
 static void set_anticipation_state()
 {
-  int state;
+  bool state;
 
   if (current_map!=NULL && map_write)
     {
-      state=CL_Lua::getparam(1);
+      state=(((float) CL_Lua::getparam(1))!=0.);
 
       current_map->set_anticipation_state(state);
     }
@@ -1172,11 +1256,11 @@ static void get_preview_state()
  */
 static void set_preview_state()
 {
-  int state;
+  bool state;
 
   if (current_map!=NULL && map_write)
     {
-      state=CL_Lua::getparam(1);
+       state=(((float) CL_Lua::getparam(1))!=0.);
 
       current_map->set_preview_state(state);
     }
@@ -1299,11 +1383,11 @@ static void set_curse_y()
  */
 static void set_curse_state()
 {
-  int state;
+  bool state;
 
   if (current_map!=NULL && map_write)
     {
-      state=CL_Lua::getparam(1);
+      state=(((float) CL_Lua::getparam(1))!=0.);
 
       current_map->set_curse_state(state);
     }
@@ -1477,53 +1561,53 @@ static void is_block_ok()
  */
 void U61_Script::record_all()
 {
-  CL_Lua::record(C_RESET_BLOCK,reset_block);
-  CL_Lua::record(C_CENTER_BLOCK,center_block);
-  CL_Lua::record(C_GET_BLOCK_X,get_block_x);
-  CL_Lua::record(C_GET_BLOCK_Y,get_block_y);
-  CL_Lua::record(C_SET_BLOCK_X,set_block_x);
-  CL_Lua::record(C_SET_BLOCK_Y,set_block_y);
-  CL_Lua::record(C_ADD_ITEM,add_item);
-  CL_Lua::record(C_GET_NB_ITEMS,get_nb_items);
-  CL_Lua::record(C_GET_ITEM_X,get_item_x);
-  CL_Lua::record(C_GET_ITEM_Y,get_item_y);
-  CL_Lua::record(C_GET_ITEM_COLOR,get_item_color);
-  CL_Lua::record(C_SET_ITEM_X,set_item_x);
-  CL_Lua::record(C_SET_ITEM_Y,set_item_y);
-  CL_Lua::record(C_SET_ITEM_COLOR,set_item_color);
-  CL_Lua::record(C_GET_WIDTH,get_width);
-  CL_Lua::record(C_GET_HEIGHT,get_height);
-  CL_Lua::record(C_GET_SQUARE_COLOR,get_square_color);
-  CL_Lua::record(C_SET_SQUARE_COLOR,set_square_color);
-  CL_Lua::record(C_GET_TIME,get_time);
-  CL_Lua::record(C_GET_SCORE,get_score);
-  CL_Lua::record(C_SET_SCORE,set_score);
-  CL_Lua::record(C_ADD_SCORE,add_score);
-  CL_Lua::record(C_GET_GLOBAL,get_global);
-  CL_Lua::record(C_SET_GLOBAL,set_global);
-  CL_Lua::record(C_GET_ANTICIPATION_STATE,get_anticipation_state);
-  CL_Lua::record(C_SET_ANTICIPATION_STATE,set_anticipation_state);
-  CL_Lua::record(C_GET_PREVIEW_STATE,get_preview_state);
-  CL_Lua::record(C_SET_PREVIEW_STATE,set_preview_state);
-  CL_Lua::record(C_BLOW_UP_SQUARE,blow_up_square);
-  CL_Lua::record(C_IS_SQUARE_EXPLODING,is_square_exploding);
-  CL_Lua::record(C_GET_CURSE_X,get_curse_x);
-  CL_Lua::record(C_GET_CURSE_Y,get_curse_y);
-  CL_Lua::record(C_GET_CURSE_STATE,get_curse_state);
-  CL_Lua::record(C_SET_CURSE_X,set_curse_x);
-  CL_Lua::record(C_SET_CURSE_Y,set_curse_y);
-  CL_Lua::record(C_SET_CURSE_STATE,set_curse_state);
-  CL_Lua::record(C_IS_CURSE_AVAILABLE,is_curse_available);
-  CL_Lua::record(C_SEND_CURSE,send_curse);
-  CL_Lua::record(C_GET_CURSE_AGE,get_curse_age);
-  CL_Lua::record(C_REGISTER_CURSE,register_curse);
-  CL_Lua::record(C_CANCEL_CURSE,cancel_curse);
-  CL_Lua::record(C_GET_OLDEST_CURSE,get_oldest_curse);
-  CL_Lua::record(C_GET_NB_CURSES,get_nb_curses);
-  CL_Lua::record(C_GET_NB_ANTIDOTES,get_nb_antidotes);
-  CL_Lua::record(C_ADD_ANTIDOTE,add_antidote);
-  CL_Lua::record(C_DELETE_ANTIDOTE,delete_antidote);
-  CL_Lua::record(C_IS_BLOCK_OK,is_block_ok);
+  CL_Lua::record(U61_SCRIPT_C_RESET_BLOCK,reset_block);
+  CL_Lua::record(U61_SCRIPT_C_CENTER_BLOCK,center_block);
+  CL_Lua::record(U61_SCRIPT_C_GET_BLOCK_X,get_block_x);
+  CL_Lua::record(U61_SCRIPT_C_GET_BLOCK_Y,get_block_y);
+  CL_Lua::record(U61_SCRIPT_C_SET_BLOCK_X,set_block_x);
+  CL_Lua::record(U61_SCRIPT_C_SET_BLOCK_Y,set_block_y);
+  CL_Lua::record(U61_SCRIPT_C_ADD_ITEM,add_item);
+  CL_Lua::record(U61_SCRIPT_C_GET_NB_ITEMS,get_nb_items);
+  CL_Lua::record(U61_SCRIPT_C_GET_ITEM_X,get_item_x);
+  CL_Lua::record(U61_SCRIPT_C_GET_ITEM_Y,get_item_y);
+  CL_Lua::record(U61_SCRIPT_C_GET_ITEM_COLOR,get_item_color);
+  CL_Lua::record(U61_SCRIPT_C_SET_ITEM_X,set_item_x);
+  CL_Lua::record(U61_SCRIPT_C_SET_ITEM_Y,set_item_y);
+  CL_Lua::record(U61_SCRIPT_C_SET_ITEM_COLOR,set_item_color);
+  CL_Lua::record(U61_SCRIPT_C_GET_WIDTH,get_width);
+  CL_Lua::record(U61_SCRIPT_C_GET_HEIGHT,get_height);
+  CL_Lua::record(U61_SCRIPT_C_GET_SQUARE_COLOR,get_square_color);
+  CL_Lua::record(U61_SCRIPT_C_SET_SQUARE_COLOR,set_square_color);
+  CL_Lua::record(U61_SCRIPT_C_GET_TIME,get_time);
+  CL_Lua::record(U61_SCRIPT_C_GET_SCORE,get_score);
+  CL_Lua::record(U61_SCRIPT_C_SET_SCORE,set_score);
+  CL_Lua::record(U61_SCRIPT_C_ADD_SCORE,add_score);
+  CL_Lua::record(U61_SCRIPT_C_GET_GLOBAL,get_global);
+  CL_Lua::record(U61_SCRIPT_C_SET_GLOBAL,set_global);
+  CL_Lua::record(U61_SCRIPT_C_GET_ANTICIPATION_STATE,get_anticipation_state);
+  CL_Lua::record(U61_SCRIPT_C_SET_ANTICIPATION_STATE,set_anticipation_state);
+  CL_Lua::record(U61_SCRIPT_C_GET_PREVIEW_STATE,get_preview_state);
+  CL_Lua::record(U61_SCRIPT_C_SET_PREVIEW_STATE,set_preview_state);
+  CL_Lua::record(U61_SCRIPT_C_BLOW_UP_SQUARE,blow_up_square);
+  CL_Lua::record(U61_SCRIPT_C_IS_SQUARE_EXPLODING,is_square_exploding);
+  CL_Lua::record(U61_SCRIPT_C_GET_CURSE_X,get_curse_x);
+  CL_Lua::record(U61_SCRIPT_C_GET_CURSE_Y,get_curse_y);
+  CL_Lua::record(U61_SCRIPT_C_GET_CURSE_STATE,get_curse_state);
+  CL_Lua::record(U61_SCRIPT_C_SET_CURSE_X,set_curse_x);
+  CL_Lua::record(U61_SCRIPT_C_SET_CURSE_Y,set_curse_y);
+  CL_Lua::record(U61_SCRIPT_C_SET_CURSE_STATE,set_curse_state);
+  CL_Lua::record(U61_SCRIPT_C_IS_CURSE_AVAILABLE,is_curse_available);
+  CL_Lua::record(U61_SCRIPT_C_SEND_CURSE,send_curse);
+  CL_Lua::record(U61_SCRIPT_C_GET_CURSE_AGE,get_curse_age);
+  CL_Lua::record(U61_SCRIPT_C_REGISTER_CURSE,register_curse);
+  CL_Lua::record(U61_SCRIPT_C_CANCEL_CURSE,cancel_curse);
+  CL_Lua::record(U61_SCRIPT_C_GET_OLDEST_CURSE,get_oldest_curse);
+  CL_Lua::record(U61_SCRIPT_C_GET_NB_CURSES,get_nb_curses);
+  CL_Lua::record(U61_SCRIPT_C_GET_NB_ANTIDOTES,get_nb_antidotes);
+  CL_Lua::record(U61_SCRIPT_C_ADD_ANTIDOTE,add_antidote);
+  CL_Lua::record(U61_SCRIPT_C_DELETE_ANTIDOTE,delete_antidote);
+  CL_Lua::record(U61_SCRIPT_C_IS_BLOCK_OK,is_block_ok);
 }
 
 
