@@ -66,9 +66,9 @@ class U61_ServerDispatcher : public U61_Dispatcher
   void close(U61_Connection *c);
  protected:
 
-  U61_History history[MAX_PLAYER_ID];
+  U61_History history[U61_DISPATCHER_MAX_PLAYER_ID];
 
-  vector<U61_Connection *> connection;
+  std::vector<U61_Connection *> connection;
 };
 
 #endif
