@@ -46,9 +46,20 @@
 #include "debug.h"
 
 /*---------------------------------------------------------------------------
- variants
+ constants
  ---------------------------------------------------------------------------*/
 
+#define U61_SERVERPROTOCOL_LISTENING           10
+#define U61_SERVERPROTOCOL_CLIENT_ACCEPTED     11
+#define U61_SERVERPROTOCOL_SCRIPT_NAME_SENT    30
+#define U61_SERVERPROTOCOL_SCRIPT_SENT         31
+#define U61_SERVERPROTOCOL_ID0_SENT            40
+#define U61_SERVERPROTOCOL_ID1_SENT            41
+#define U61_SERVERPROTOCOL_INITIAL_SPEED_SENT  42
+#define U61_SERVERPROTOCOL_ACCELERATION_SENT   43
+#define U61_SERVERPROTOCOL_CURSE_DELAY_SENT    44
+#define U61_SERVERPROTOCOL_TIME_SENT           45
+
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
@@ -65,7 +76,7 @@ U61_ServerProtocol::U61_ServerProtocol(U61_ServerDispatcher *d, int p,int ch)
   dispatcher=d;
   new_connection=0;
 
-  for (i=0;i<U61_Game::NB_NET_GROUPS-1;++i)
+  for (i=0;i<U61_GAME_NB_NET_GROUPS-1;++i)
     {
       connection[i]=NULL;
       id0[i]=-1;
@@ -81,7 +92,7 @@ U61_ServerProtocol::~U61_ServerProtocol()
 {
   int i;
 
-  for (i=0;i<U61_Game::NB_NET_GROUPS-1;++i)
+  for (i=0;i<U61_GAME_NB_NET_GROUPS-1;++i)
     {
       if (connection[i]!=NULL)
 	{
@@ -111,7 +122,7 @@ void U61_ServerProtocol::check_connection()
 
   if (game!=NULL && (client=game->receive_computer_leave())!=NULL)
     {
-      for (i=0;i<U61_Game::NB_NET_GROUPS-1;++i)
+      for (i=0;i<U61_GAME_NB_NET_GROUPS-1;++i)
 	{
 	  if (connection[i]!=NULL
 	      && connection[i]->is_associated(client))
@@ -122,7 +133,7 @@ void U61_ServerProtocol::check_connection()
 		}
 	      delete connection[i];
 
-	      evt.code=U61_Event::KILL;
+	      evt.code=U61_EVENT_KILL;
 	      evt.time=0;
 	      evt.author=evt.target=id0[i];
 	      dispatcher->put_out(evt);   
@@ -155,99 +166,99 @@ void U61_ServerProtocol::check_connection()
  */
 int U61_ServerProtocol::send_next_packet()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   switch(stage)
     {
-    case BEGIN:
-      if ((result=start_listening())==DONE)
+    case U61_PROTOCOL_BEGIN:
+      if ((result=start_listening())==U61_PROTOCOL_DONE)
 	{
-	  stage=LISTENING;
+	  stage=U61_SERVERPROTOCOL_LISTENING;
 	  U61_LOG_DEBUG("stage=LISTENING");
 	}
       break;
-    case CLIENT_ACCEPTED:
-      if ((result=send_id(connection[new_connection]))==DONE)
+    case U61_SERVERPROTOCOL_CLIENT_ACCEPTED:
+      if ((result=send_id(connection[new_connection]))==U61_PROTOCOL_DONE)
 	{
-	  stage=ID_SENT;
+	  stage=U61_PROTOCOL_ID_SENT;
 	  U61_LOG_DEBUG("stage=ID_SENT");
 	}
       break;
-    case ID_RECEIVED:
-      if ((result=send_version(connection[new_connection]))==DONE)
+    case U61_PROTOCOL_ID_RECEIVED:
+      if ((result=send_version(connection[new_connection]))==U61_PROTOCOL_DONE)
 	{
-	  stage=VERSION_SENT;
+	  stage=U61_PROTOCOL_VERSION_SENT;
 	  U61_LOG_DEBUG("stage=VERSION_SENT");
 	}
       break;
-    case VERSION_RECEIVED:
-      if ((result=send_script_name())==DONE)
+    case U61_PROTOCOL_VERSION_RECEIVED:
+      if ((result=send_script_name())==U61_PROTOCOL_DONE)
 	{
-	  stage=SCRIPT_NAME_SENT;
+	  stage=U61_SERVERPROTOCOL_SCRIPT_NAME_SENT;
 	  U61_LOG_DEBUG("stage=SCRIPT_NAME_SENT");
 	}
       break;
-    case SCRIPT_NAME_SENT:
-      if ((result=send_script())==DONE)
+    case U61_SERVERPROTOCOL_SCRIPT_NAME_SENT:
+      if ((result=send_script())==U61_PROTOCOL_DONE)
 	{
-	  stage=SCRIPT_SENT;
+	  stage=U61_SERVERPROTOCOL_SCRIPT_SENT;
 	  U61_LOG_DEBUG("stage=SCRIPT_SENT");
 	}
       break;
-    case SCRIPT_SENT:
-      if ((result=send_id0())==DONE)
+    case U61_SERVERPROTOCOL_SCRIPT_SENT:
+      if ((result=send_id0())==U61_PROTOCOL_DONE)
 	{
-	  stage=ID0_SENT;
+	  stage=U61_SERVERPROTOCOL_ID0_SENT;
 	  U61_LOG_DEBUG("stage=ID0_SENT");
 	}
       break;
-    case ID0_SENT:
-      if ((result=send_id1())==DONE)
+    case U61_SERVERPROTOCOL_ID0_SENT:
+      if ((result=send_id1())==U61_PROTOCOL_DONE)
 	{
-	  stage=ID1_SENT;
+	  stage=U61_SERVERPROTOCOL_ID1_SENT;
 	  U61_LOG_DEBUG("stage=ID1_SENT");
 	}
       break;
-    case ID1_SENT:
-      if ((result=send_initial_speed())==DONE)
+    case U61_SERVERPROTOCOL_ID1_SENT:
+      if ((result=send_initial_speed())==U61_PROTOCOL_DONE)
 	{
-	  stage=INITIAL_SPEED_SENT;
+	  stage=U61_SERVERPROTOCOL_INITIAL_SPEED_SENT;
 	  U61_LOG_DEBUG("stage=INITIAL_SPEED_SENT");
 	}
       break;
-    case INITIAL_SPEED_SENT:
-      if ((result=send_acceleration())==DONE)
+    case U61_SERVERPROTOCOL_INITIAL_SPEED_SENT:
+      if ((result=send_acceleration())==U61_PROTOCOL_DONE)
 	{
-	  stage=ACCELERATION_SENT;
+	  stage=U61_SERVERPROTOCOL_ACCELERATION_SENT;
 	  U61_LOG_DEBUG("stage=ACCELERATION_SENT");
 	}
       break;
-    case ACCELERATION_SENT:
-      if ((result=send_curse_delay())==DONE)
+    case U61_SERVERPROTOCOL_ACCELERATION_SENT:
+      if ((result=send_curse_delay())==U61_PROTOCOL_DONE)
 	{
-	  stage=CURSE_DELAY_SENT;
+	  stage=U61_SERVERPROTOCOL_CURSE_DELAY_SENT;
 	  U61_LOG_DEBUG("stage=CURSE_DELAY_SENT");
 	}
       break;
-    case CURSE_DELAY_SENT:
-      if ((result=send_time())==DONE)
+    case U61_SERVERPROTOCOL_CURSE_DELAY_SENT:
+      if ((result=send_time())==U61_PROTOCOL_DONE)
 	{
-	  stage=TIME_SENT;
+	  stage=U61_SERVERPROTOCOL_TIME_SENT;
 	  U61_LOG_DEBUG("stage=TIME_SENT");
 	}
       break;
-    case TIME_SENT:
-      if ((result=send_ready(connection[new_connection]))==DONE)
+    case U61_SERVERPROTOCOL_TIME_SENT:
+      if ((result=send_ready(connection[new_connection]))==U61_PROTOCOL_DONE)
 	{
-	  stage=READY_SENT;
+	  stage=U61_PROTOCOL_READY_SENT;
 	  U61_LOG_DEBUG("stage=READY_SENT");
 	}
       break;
-    case READY_RECEIVED:
+    case U61_PROTOCOL_READY_RECEIVED:
       dispatcher->open(connection[new_connection]);
 
       U61_LOG_DEBUG("stage=LISTENING");
-      stage=LISTENING;
+      stage=U61_SERVERPROTOCOL_LISTENING;
       break;
     }
 
@@ -264,35 +275,35 @@ int U61_ServerProtocol::send_next_packet()
  */
 int U61_ServerProtocol::recv_next_packet()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   switch(stage)
     {
-    case LISTENING:
-      if ((result=accept_client())==DONE)
+    case U61_SERVERPROTOCOL_LISTENING:
+      if ((result=accept_client())==U61_PROTOCOL_DONE)
 	{
-	  stage=CLIENT_ACCEPTED;
+	  stage=U61_SERVERPROTOCOL_CLIENT_ACCEPTED;
 	  U61_LOG_DEBUG("stage=CLIENT_ACCEPTED");
 	}
       break;
-    case ID_SENT:
-      if ((result=recv_id(connection[new_connection]))==DONE)
+    case U61_PROTOCOL_ID_SENT:
+      if ((result=recv_id(connection[new_connection]))==U61_PROTOCOL_DONE)
 	{
-	  stage=ID_RECEIVED;
+	  stage=U61_PROTOCOL_ID_RECEIVED;
 	  U61_LOG_DEBUG("stage=ID_RECEIVED");
 	}
       break;
-    case VERSION_SENT:
-      if ((result=recv_version(connection[new_connection]))==DONE)
+    case U61_PROTOCOL_VERSION_SENT:
+      if ((result=recv_version(connection[new_connection]))==U61_PROTOCOL_DONE)
 	{
-	  stage=VERSION_RECEIVED;
+	  stage=U61_PROTOCOL_VERSION_RECEIVED;
 	  U61_LOG_DEBUG("stage=VERSION_RECEIVED");
 	}
       break;
-    case READY_SENT:
-      if ((result=recv_ready(connection[new_connection]))==DONE)
+    case U61_PROTOCOL_READY_SENT:
+      if ((result=recv_ready(connection[new_connection]))==U61_PROTOCOL_DONE)
 	{
-	  stage=READY_RECEIVED;
+	  stage=U61_PROTOCOL_READY_RECEIVED;
 	  U61_LOG_DEBUG("stage=READY_RECEIVED");
 	}
       break;
@@ -310,22 +321,22 @@ int U61_ServerProtocol::recv_next_packet()
  */
 int U61_ServerProtocol::start_listening()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   try 
     {
-      game=CL_Network::create_game(GAME_ID,port);
+      game=CL_Network::create_game(U61_PROTOCOL_GAME_ID,port);
     }
   catch (CL_Error e)
     {
-      result=FAILED;
+      result=U61_PROTOCOL_FAILED;
       diagnostic+=e.message;
       game=NULL;
     }
 
   if (game!=NULL)
     {
-      result=DONE;
+      result=U61_PROTOCOL_DONE;
     };
   
   return result;
@@ -339,14 +350,14 @@ int U61_ServerProtocol::start_listening()
  */
 int U61_ServerProtocol::accept_client()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
   const CL_NetComputer *computer;
   
   if ((computer=game->receive_computer_join())!=NULL)
     {
       if ((new_connection=get_free_connection())<0)
 	{
-	  result=FAILED;
+	  result=U61_PROTOCOL_FAILED;
 	}
       else
 	{  
@@ -359,7 +370,7 @@ int U61_ServerProtocol::accept_client()
 	  connection[new_connection]=new 
 	    U61_Connection(game,(CL_NetComputer *) computer,
 			   channel+new_connection,true);        
-	  result=DONE;
+	  result=U61_PROTOCOL_DONE;
 	}
     }
   
@@ -376,7 +387,7 @@ int U61_ServerProtocol::get_free_connection()
   int i;
   int result=-1;
 
-  for (i=0;i<U61_Game::NB_NET_GROUPS-1;++i)
+  for (i=0;i<U61_GAME_NB_NET_GROUPS-1;++i)
     {
       if (connection[i]==NULL)
 	{
@@ -395,8 +406,8 @@ int U61_ServerProtocol::get_free_connection()
  */
 int U61_ServerProtocol::send_script_name()
 {
-  int result=LATER;
-  char script_name[U61_STRING_SIZE];
+  int result=U61_PROTOCOL_LATER;
+  char script_name[U61_CONST_STRING_SIZE];
 
   strncpy(script_name,
 	  U61_Global::config.script_file,
@@ -404,7 +415,7 @@ int U61_ServerProtocol::send_script_name()
   U61_Platform::strip_remote_script_path(script_name);
   if (connection[new_connection]->send(script_name,sizeof(script_name)-1))
     {
-      result=DONE;
+      result=U61_PROTOCOL_DONE;
     }
  
   return result;
@@ -416,9 +427,9 @@ int U61_ServerProtocol::send_script_name()
  */
 int U61_ServerProtocol::send_script()
 {
-  int result=LATER;
-  char script[U61_SCRIPT_SIZE];
-  char script_name[U61_STRING_SIZE];
+  int result=U61_PROTOCOL_LATER;
+  char script[U61_CONST_SCRIPT_SIZE];
+  char script_name[U61_CONST_STRING_SIZE];
   FILE *f;
   int c;
   int pos=0;
@@ -427,14 +438,14 @@ int U61_ServerProtocol::send_script()
   f=fopen(script_name,"rb");
   if (f!=NULL)
     {
-      while ((c=fgetc(f))!=EOF && pos<U61_SCRIPT_SIZE)
+      while ((c=fgetc(f))!=EOF && pos<U61_CONST_SCRIPT_SIZE)
 	{
 	  script[pos++]=c;
 	}
       fclose(f);
       if (connection[new_connection]->send(script,sizeof(script)-1))
 	{
-	  result=DONE;
+	  result=U61_PROTOCOL_DONE;
 	}
     }
   else
@@ -442,7 +453,7 @@ int U61_ServerProtocol::send_script()
       diagnostic="Could not open script file \"";
       diagnostic+=script_name;
       diagnostic+="\"";
-      result=FAILED;
+      result=U61_PROTOCOL_FAILED;
     }
 
   return result;
@@ -454,14 +465,14 @@ int U61_ServerProtocol::send_script()
  */
 int U61_ServerProtocol::send_id0()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
   int id;
 
   id=U61_Global::game.find_free_player_id0();
   if (connection[new_connection]->send(id))
     {
       id0[new_connection]=id;
-      result=DONE;
+      result=U61_PROTOCOL_DONE;
     }
  
   return result;
@@ -473,14 +484,14 @@ int U61_ServerProtocol::send_id0()
  */
 int U61_ServerProtocol::send_id1()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
   int id;
 
   id=U61_Global::game.find_free_player_id1();
   if (connection[new_connection]->send(id))
     {
       id1[new_connection]=id;
-      result=DONE;
+      result=U61_PROTOCOL_DONE;
     }
  
   return result;
@@ -493,11 +504,11 @@ int U61_ServerProtocol::send_id1()
  */
 int U61_ServerProtocol::send_initial_speed()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   if (connection[new_connection]->send(U61_Global::config.initial_speed))
     {
-      result=DONE;
+      result=U61_PROTOCOL_DONE;
     }
  
   return result;
@@ -510,11 +521,11 @@ int U61_ServerProtocol::send_initial_speed()
  */
 int U61_ServerProtocol::send_acceleration()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   if (connection[new_connection]->send(U61_Global::config.acceleration))
     {
-      result=DONE;
+      result=U61_PROTOCOL_DONE;
     }
  
   return result;
@@ -527,11 +538,11 @@ int U61_ServerProtocol::send_acceleration()
  */
 int U61_ServerProtocol::send_curse_delay()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   if (connection[new_connection]->send(U61_Global::config.curse_delay))
     {
-      result=DONE;
+      result=U61_PROTOCOL_DONE;
     }
  
   return result;
@@ -544,11 +555,11 @@ int U61_ServerProtocol::send_curse_delay()
  */
 int U61_ServerProtocol::send_time()
 {
-  int result=LATER;
+  int result=U61_PROTOCOL_LATER;
 
   if (connection[new_connection]->send(U61_Time::for_event()))
     {
-      result=DONE;
+      result=U61_PROTOCOL_DONE;
     }
  
   return result;
@@ -561,7 +572,7 @@ int U61_ServerProtocol::send_time()
  */
 void U61_ServerProtocol::handle_error(int result)
 {
-  if (result==FAILED)
+  if (result==U61_PROTOCOL_FAILED)
     {
       U61_LOG_WARNING("Network server protocol error on connection "
 		      <<new_connection
@@ -581,7 +592,7 @@ void U61_ServerProtocol::handle_error(int result)
            * the opening of the listening socket.
            * so we restart everything from scratch
            */    
-	  stage=BEGIN;
+	  stage=U61_PROTOCOL_BEGIN;
 	}
       else
 	{
@@ -590,7 +601,7 @@ void U61_ServerProtocol::handle_error(int result)
 	   * on an opened socket, therefore we go back to LISTENING mode
 	   * ie accept new connection on the listening socket
 	   */
-	  stage=LISTENING;
+	  stage=U61_SERVERPROTOCOL_LISTENING;
 	}
     }
 }
