@@ -62,9 +62,9 @@ U61_SpeedMenu::U61_SpeedMenu(U61_Menu *parent,
 {
     config=conf;
     add_item(new U61_Number("Initial speed",
-             &(conf->initial_speed),0,U61_Map::MAX_USER_SPEED));
+             &(conf->initial_speed),0,U61_MAP_MAX_USER_SPEED));
     add_item(new U61_Number("Acceleration",
-             &(conf->acceleration),0,U61_Map::MAX_USER_ACCEL));
+             &(conf->acceleration),0,U61_MAP_MAX_USER_ACCEL));
     add_item(new U61_Number("Curse delay",
              &(conf->curse_delay),2,60));
     select(0);
