@@ -43,9 +43,12 @@
 #include "debug.h"
 
 /*---------------------------------------------------------------------------
- variants
+ constants
  ---------------------------------------------------------------------------*/
 
+#define U61_TIME_TIME_UNIT         10
+#define U61_TIME_IDLE_DELAY         5
+ 
 /*--------------------------------------------------------------------------*/
 /*
  * contains the offset that has to be substracted to get_time()
@@ -104,7 +107,7 @@ unsigned int U61_Time::last_for_display;
  */
 void U61_Time::reset(unsigned int time)
 {
-    reset_offset=CL_System::get_time()-time*TIME_UNIT;
+    reset_offset=CL_System::get_time()-time*U61_TIME_TIME_UNIT;
     alter_offset=0;
     pause_offset=0;
     paused=false;
@@ -174,7 +177,7 @@ unsigned int U61_Time::for_logic()
  */
 unsigned int U61_Time::for_effect()
 {
-    return CL_System::get_time()/TIME_UNIT;
+    return CL_System::get_time()/U61_TIME_TIME_UNIT;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -185,7 +188,7 @@ unsigned int U61_Time::for_effect()
  */
 void U61_Time::alter(int delta)
 {
-    alter_offset-=delta*TIME_UNIT;
+    alter_offset-=delta*U61_TIME_TIME_UNIT;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -344,7 +347,7 @@ int U61_Time::system_time()
         time=CL_System::get_time();
     }
 
-    return (time-reset_offset-alter_offset-pause_offset)/TIME_UNIT;
+    return (time-reset_offset-alter_offset-pause_offset)/U61_TIME_TIME_UNIT;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -355,6 +358,6 @@ int U61_Time::system_time()
  */
 void U61_Time::idle()
 {
-  CL_System::sleep(IDLE_DELAY);
+  CL_System::sleep(U61_TIME_IDLE_DELAY);
   U61_LOG_DEBUG("game is idle");
 }
